@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -29,6 +29,7 @@
 #include <map>
 #include <list>
 #include <boost/lexical_cast.hpp>
+#include <boost/filesystem.hpp>
 
 #if ORTHANC_BUILD_UNIT_TESTS == 1
 #  include <gtest/gtest_prod.h>
@@ -83,7 +84,7 @@ namespace Orthanc
     ZipWriter writer_;
 
   public:
-    explicit HierarchicalZipWriter(const char* path);
+    explicit HierarchicalZipWriter(const boost::filesystem::path& path);
 
     HierarchicalZipWriter(ZipWriter::IOutputStream* stream,  // transfers ownership
                           bool isZip64);
