@@ -24,6 +24,7 @@
 
 #pragma once
 
+#include "DicomConnectionInfo.h"
 #include "DicomFindAnswers.h"
 
 #include <list>
@@ -40,9 +41,6 @@ namespace Orthanc
     virtual void Handle(DicomFindAnswers& answers,
                         const DicomMap& input,
                         const std::list<DicomTag>& sequencesToReturn,
-                        const std::string& remoteIp,
-                        const std::string& remoteAet,
-                        const std::string& calledAet,
-                        ModalityManufacturer manufacturer) = 0;
+                        const DicomConnectionInfo& connection) = 0;
   };
 }
