@@ -44,6 +44,8 @@ namespace Orthanc
     virtual uint16_t Handle(DcmDataset& dicom,
                             const std::string& remoteIp,
                             const std::string& remoteAet,
-                            const std::string& calledAet) = 0;
+                            const std::string& calledAet,
+                            uint16_t originatorMessageId,
+                            const std::string& originatorAet) = 0;
   };
 }
