@@ -141,7 +141,7 @@ static OFCondition acceptUnknownContextsWithTransferSyntax(
   T_ASC_SC_ROLE acceptedRole)
 {
   int n, i, k;
-  DUL_PRESENTATIONCONTEXT *dpc;
+  const DUL_PRESENTATIONCONTEXT *dpc;
   T_ASC_PresentationContext pc;
 
   n = ASC_countPresentationContexts(params);
@@ -1183,8 +1183,9 @@ namespace Orthanc
           (server_.GetStorageCommitmentRequestHandlerFactory().
            ConstructStorageCommitmentRequestHandler());
 
-        handler->HandleRequest(transactionUid, sopClassUid, sopInstanceUid,
-                               remoteIp_, remoteAet_, calledAet_);
+        DicomConnectionInfo connection(remoteIp_, remoteAet_, calledAet_);
+
+        handler->HandleRequest(transactionUid, sopClassUid, sopInstanceUid, connection);
         
         dimseStatus = 0;  // Success
       }
@@ -1335,9 +1336,11 @@ namespace Orthanc
           (server_.GetStorageCommitmentRequestHandlerFactory().
            ConstructStorageCommitmentRequestHandler());
 
+        DicomConnectionInfo connection(remoteIp_, remoteAet_, calledAet_);
+
         handler->HandleReport(transactionUid, successSopClassUid, successSopInstanceUid,
                               failedSopClassUid, failedSopInstanceUid, failureReasons,
-                              remoteIp_, remoteAet_, calledAet_);
+                              connection);
         
         dimseStatus = 0;  // Success
       }
