@@ -112,13 +112,13 @@ static void HandleExistentButEmptyReferencedStudyOrPatientSequenceAttributes(Dcm
   // in case the sequence attribute contains exactly one item with an empty
   // ReferencedSOPClassUID and an empty ReferencedSOPInstanceUID, remove the item
   if( dataset->findAndGetElement( sequenceTagKey, sequenceAttribute ).good() &&
-      ( (DcmSequenceOfItems*)sequenceAttribute )->card() == 1 &&
-      ( (DcmSequenceOfItems*)sequenceAttribute )->getItem(0)->findAndGetElement( DCM_ReferencedSOPClassUID, referencedSOPClassUIDAttribute ).good() &&
+      ( reinterpret_cast<DcmSequenceOfItems*>(sequenceAttribute) )->card() == 1 &&
+      ( reinterpret_cast<DcmSequenceOfItems*>(sequenceAttribute) )->getItem(0)->findAndGetElement( DCM_ReferencedSOPClassUID, referencedSOPClassUIDAttribute ).good() &&
       referencedSOPClassUIDAttribute->getLength() == 0 &&
-      ( (DcmSequenceOfItems*)sequenceAttribute )->getItem(0)->findAndGetElement( DCM_ReferencedSOPInstanceUID, referencedSOPInstanceUIDAttribute, OFFalse ).good() &&
+      ( reinterpret_cast<DcmSequenceOfItems*>(sequenceAttribute) )->getItem(0)->findAndGetElement( DCM_ReferencedSOPInstanceUID, referencedSOPInstanceUIDAttribute, OFFalse ).good() &&
       referencedSOPInstanceUIDAttribute->getLength() == 0 )
   {
-    DcmItem *item = ((DcmSequenceOfItems*)sequenceAttribute)->remove( ((DcmSequenceOfItems*)sequenceAttribute)->getItem(0) );
+    DcmItem *item = (reinterpret_cast<DcmSequenceOfItems*>(sequenceAttribute))->remove( (reinterpret_cast<DcmSequenceOfItems*>(sequenceAttribute))->getItem(0) );
     delete item;
   }
 }
@@ -239,10 +239,10 @@ namespace Orthanc
             {
               ParsedDicomFile query(*requestIdentifiers);
               FixWorklistQuery(query);
-
-              data.worklistHandler_->Handle(data.answers_, query,
-                                            *data.remoteIp_, *data.remoteAet_,
+              DicomConnectionInfo connection(*data.remoteIp_, *data.remoteAet_,
                                             *data.calledAet_, modality.GetManufacturer());
+
+              data.worklistHandler_->Handle(data.answers_, query, connection);
               ok = true;
             }
             else
@@ -284,10 +284,10 @@ namespace Orthanc
 
               DicomMap filtered;
               FixFindQuery(filtered, input);
+              DicomConnectionInfo connection(*data.remoteIp_, *data.remoteAet_,
+                                            *data.calledAet_, modality.GetManufacturer());
 
-              data.findHandler_->Handle(data.answers_, filtered, sequencesToReturn,
-                                        *data.remoteIp_, *data.remoteAet_,
-                                        *data.calledAet_, modality.GetManufacturer());
+              data.findHandler_->Handle(data.answers_, filtered, sequencesToReturn, connection);
               ok = true;
             }
             else
