@@ -1694,16 +1694,28 @@ namespace Orthanc
                                     MimeType& mime,
                                     unsigned int frameId) const
   {
+    DcmDataset* dcmDataset = GetDcmtkObjectConst().getDataset();
+
+    if (dcmDataset == NULL)
+    {
+      throw OrthancException(ErrorCode_InternalError);
+    }
+
+    if (!this->HasTag(DICOM_TAG_PIXEL_DATA) &&
+        !DicomImageDecoder::IsPsmctRle1(*dcmDataset))
+    {
+      throw OrthancException(ErrorCode_BadRequest, "Cannot extract a frame from a DICOM file that does not have pixel data.");
+    }
+
     if (pimpl_->frameIndex_.get() == NULL)
     {
-      assert(pimpl_->file_ != NULL &&
-             GetDcmtkObjectConst().getDataset() != NULL);
-      pimpl_->frameIndex_.reset(new DicomFrameIndex(*GetDcmtkObjectConst().getDataset()));
+      assert(pimpl_->file_ != NULL);
+      pimpl_->frameIndex_.reset(new DicomFrameIndex(*dcmDataset));
     }
 
     pimpl_->frameIndex_->GetRawFrame(target, frameId);
 
-    E_TransferSyntax transferSyntax = GetDcmtkObjectConst().getDataset()->getCurrentXfer();
+    E_TransferSyntax transferSyntax = dcmDataset->getCurrentXfer();
     switch (transferSyntax)
     {
       case EXS_JPEGProcess1:
@@ -1812,6 +1824,67 @@ namespace Orthanc
     }
   }
 
+  ImageAccessor* ParsedDicomFile::GetRawFrameForInplaceModification(unsigned int frame)
+  {
+    E_TransferSyntax transferSyntax = GetDcmtkObjectConst().getDataset()->getCurrentXfer();
+
+    bool ok = false;
+    switch (Toolbox::DetectEndianness())
+    {
+      case Endianness_Little:
+        if (transferSyntax == EXS_LittleEndianImplicit ||
+            transferSyntax == EXS_LittleEndianExplicit)
+        {
+          ok = true;
+        }
+        break;
+
+      case Endianness_Big:
+        if (transferSyntax == EXS_BigEndianImplicit ||
+            transferSyntax == EXS_BigEndianExplicit)
+        {
+          ok = true;
+        }
+        break;
+
+      default:
+        throw OrthancException(ErrorCode_InternalError);
+    }
+
+    if (!ok)
+    {
+      throw OrthancException(ErrorCode_NotImplemented, "ParsedDicomFile::GetRawFrameForInplaceModification() only works with uncompressed transfer syntaxes and matching host endianness");
+    }
+
+    if (pimpl_->frameIndex_.get() == NULL)
+    {
+      assert(pimpl_->file_ != NULL &&
+             GetDcmtkObjectConst().getDataset() != NULL);
+      pimpl_->frameIndex_.reset(new DicomFrameIndex(*GetDcmtkObjectConst().getDataset()));
+    }
+
+    DicomMap m;
+    std::set<DicomTag> ignoreTagLength;
+    FromDcmtkBridge::ExtractDicomSummary(m, *GetDcmtkObjectConst().getDataset(), DicomImageInformation::GetUsefulTagLength(), ignoreTagLength);
+
+    DicomImageInformation info(m);
+    PixelFormat format;
+    
+    if (!info.ExtractPixelFormat(format, false))
+    {
+      LOG(WARNING) << "Unsupported DICOM image: " << info.GetBitsStored() 
+                   << "bpp, " << info.GetChannelCount() << " channels, " 
+                   << (info.IsSigned() ? "signed" : "unsigned")
+                   << (info.IsPlanar() ? ", planar, " : ", non-planar, ")
+                   << EnumerationToString(info.GetPhotometricInterpretation())
+                   << " photometric interpretation";
+      throw OrthancException(ErrorCode_NotImplemented);
+    }
+
+    std::unique_ptr<ImageAccessor> img(new ImageAccessor());
+    img->AssignWritable(format, info.GetWidth(), info.GetHeight(), info.GetWidth() * GetBytesPerPixel(format), pimpl_->frameIndex_->GetRawFrameBuffer(frame));
+    return img.release();
+  }
 
   static bool HasGenericGroupLength(const DicomPath& path)
   {
