@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -192,7 +192,7 @@ namespace Orthanc
     ErrorCode_DirectoryOverFile = 2000    /*!< The directory to be created is already occupied by a regular file */,
     ErrorCode_FileStorageCannotWrite = 2001    /*!< Unable to create a subdirectory or a file in the file storage */,
     ErrorCode_DirectoryExpected = 2002    /*!< The specified path does not point to a directory */,
-    ErrorCode_HttpPortInUse = 2003    /*!< The TCP port of the HTTP server is privileged or already in use */,
+    ErrorCode_HttpPortInUse = 2003    /*!< The TCP port of the HTTP server is privileged or already in use or one of the HTTP bind addresses does not exist */,
     ErrorCode_DicomPortInUse = 2004    /*!< The TCP port of the DICOM server is privileged or already in use */,
     ErrorCode_BadHttpStatusInRest = 2005    /*!< This HTTP status is not allowed in a REST API */,
     ErrorCode_RegularFileExpected = 2006    /*!< The specified path does not point to a regular file */,
@@ -234,6 +234,7 @@ namespace Orthanc
     ErrorCode_AlreadyExistingTag = 2042    /*!< Cannot override the value of a tag that already exists */,
     ErrorCode_NoStorageCommitmentHandler = 2043    /*!< No request handler factory for DICOM N-ACTION SCP (storage commitment) */,
     ErrorCode_NoCGetHandler = 2044    /*!< No request handler factory for DICOM C-GET SCP */,
+    ErrorCode_DicomGetUnavailable = 2045    /*!< DicomUserConnection: The C-GET command is not supported by the remote SCP */,
     ErrorCode_UnsupportedMediaType = 3000    /*!< Unsupported media type */,
     ErrorCode_START_PLUGINS = 1000000
   };
@@ -793,6 +794,28 @@ namespace Orthanc
     ResourceType_Instance = 4
   };
 
+  enum RetrieveMethod                         // new in Orthanc 1.12.6
+  {
+    RetrieveMethod_Move = 1,
+    RetrieveMethod_Get = 2,
+
+    RetrieveMethod_SystemDefault = 65535
+  };
+
+  enum ErrorPayloadType
+  {
+    ErrorPayloadType_None = 1,
+    ErrorPayloadType_Dimse = 2,
+    ErrorPayloadType_RetrieveJob = 3,
+  };
+
+  enum TranscodingSopInstanceUidMode
+  {
+    TranscodingSopInstanceUidMode_NoChange,   // Never change the SOP Instance UID (only allows transcoding to lossless)
+    TranscodingSopInstanceUidMode_AllowNew,   // Allow transcoding to lossless and lossy (if lossy, a new SOP Instance UID is generated)
+    TranscodingSopInstanceUidMode_Preserve    // Allow transcoding to lossless and lossy (if lossy, preserve the original SOP Instance UID)
+  };
+
 
   ORTHANC_PUBLIC
   const char* EnumerationToString(ErrorCode code);
@@ -848,6 +871,12 @@ namespace Orthanc
   ORTHANC_PUBLIC
   const char* EnumerationToString(DicomToJsonFormat format);
 
+  ORTHANC_PUBLIC
+  const char* EnumerationToString(RetrieveMethod method);
+
+  ORTHANC_PUBLIC
+  const char* EnumerationToString(ErrorPayloadType type);
+
   ORTHANC_PUBLIC
   Encoding StringToEncoding(const char* encoding);
 
@@ -881,6 +910,9 @@ namespace Orthanc
   
   ORTHANC_PUBLIC
   DicomToJsonFormat StringToDicomToJsonFormat(const std::string& format);
+
+  ORTHANC_PUBLIC
+  ErrorPayloadType StringToErrorPayloadType(const std::string& type);
   
   ORTHANC_PUBLIC
   bool LookupMimeType(MimeType& target,
@@ -903,7 +935,7 @@ namespace Orthanc
   bool IsResourceLevelAboveOrEqual(ResourceType level,
                                    ResourceType reference);
 
-ORTHANC_PUBLIC
+  ORTHANC_PUBLIC
   const char* ResourceTypeToDicomQueryRetrieveLevel(ResourceType type);
 
   ORTHANC_PUBLIC
@@ -947,4 +979,7 @@ ORTHANC_PUBLIC
 
   ORTHANC_PUBLIC
   void GetAllDicomTransferSyntaxes(std::set<DicomTransferSyntax>& target);
+
+  ORTHANC_PUBLIC 
+  RetrieveMethod StringToRetrieveMethod(const std::string& str);
 }
