@@ -69,31 +69,6 @@ namespace Orthanc
   }
 
   
-  IMemoryBuffer* MemoryStorageArea::Read(const std::string& uuid,
-                                         FileContentType type) 
-  {
-    LOG(INFO) << "Reading attachment \"" << uuid << "\" of \""
-              << static_cast<int>(type) << "\" content type";
-
-    Mutex::ScopedLock lock(mutex_);
-
-    Content::const_iterator found = content_.find(uuid);
-
-    if (found == content_.end())
-    {
-      throw OrthancException(ErrorCode_InexistentFile);
-    }
-    else if (found->second == NULL)
-    {
-      throw OrthancException(ErrorCode_InternalError);
-    }
-    else
-    {
-      return StringMemoryBuffer::CreateFromCopy(*found->second);
-    }
-  }
-      
-
   IMemoryBuffer* MemoryStorageArea::ReadRange(const std::string& uuid,
                                               FileContentType type,
                                               uint64_t start /* inclusive */,
@@ -113,6 +88,12 @@ namespace Orthanc
     }
     else
     {
+      const uint64_t size = end - start;
+      if (static_cast<uint64_t>(static_cast<size_t>(size)) != size)
+      {
+        throw OrthancException(ErrorCode_InternalError, "Buffer larger than 4GB, which is too large for Orthanc running in 32bits");
+      }
+
       Mutex::ScopedLock lock(mutex_);
 
       Content::const_iterator found = content_.find(uuid);
@@ -132,7 +113,7 @@ namespace Orthanc
       else
       {
         std::string range;
-        range.resize(end - start);
+        range.resize(static_cast<size_t>(size));
         assert(!range.empty());
 
         memcpy(&range[0], &found->second[start], range.size());
@@ -143,12 +124,6 @@ namespace Orthanc
   }
 
 
-  bool MemoryStorageArea::HasReadRange() const
-  {
-    return true;
-  }
-
-
   void MemoryStorageArea::Remove(const std::string& uuid,
                                  FileContentType type)
   {
