@@ -50,7 +50,8 @@ namespace Orthanc
                                             const char* username,
                                             HttpMethod method,
                                             const UriComponents& uri,
-                                            const HttpToolbox::Arguments& headers) ORTHANC_OVERRIDE
+                                            const HttpToolbox::Arguments& headers,
+                                            const std::string& authenticationPayload /* ignored */) ORTHANC_OVERRIDE
     {
       return false;
     }
@@ -64,7 +65,8 @@ namespace Orthanc
                         const HttpToolbox::Arguments& headers,
                         const HttpToolbox::GetArguments& arguments,
                         const void* /*bodyData*/,
-                        size_t /*bodySize*/) ORTHANC_OVERRIDE;
+                        size_t /*bodySize*/,
+                        const std::string& authenticationPayload /* ignored */) ORTHANC_OVERRIDE;
 
     bool IsListDirectoryContent() const
     {
