@@ -619,7 +619,7 @@ namespace Orthanc
       throw OrthancException(ErrorCode_InternalError);
     }
     
-    boundary = boundary.substr(0, 70);
+    boundary.resize(70);
     
     contentTypeHeader = ("multipart/" + subType + "; type=" + tmp + "; boundary=" + boundary);
   }
@@ -805,6 +805,8 @@ namespace Orthanc
   void HttpOutput::StateMachine::SendStreamItem(const void* data,
                                                 size_t size)
   {
+    LOG(TRACE) << "SendStreamItem " << size << " bytes";
+
     if (state_ != State_WritingStream)
     {
       throw OrthancException(ErrorCode_BadSequenceOfCalls);
@@ -821,6 +823,8 @@ namespace Orthanc
 
   void HttpOutput::StateMachine::CloseStream()
   {
+    LOG(TRACE) << "CloseStream";
+    
     if (state_ != State_WritingStream)
     {
       throw OrthancException(ErrorCode_BadSequenceOfCalls);
@@ -972,7 +976,7 @@ namespace Orthanc
       stateMachine_.AddHeader("Content-Disposition", "filename=\"" + std::string(filename) + "\"");
     }
 
-    stateMachine_.StartStream(contentType.c_str());
+    stateMachine_.StartStream(contentType);
 
     while (stream.ReadNextChunk())
     {
@@ -984,7 +988,7 @@ namespace Orthanc
 
   void HttpOutput::StartStream(const std::string& contentType)
   {
-    stateMachine_.StartStream(contentType.c_str());
+    stateMachine_.StartStream(contentType);
   }
 
   void HttpOutput::SendStreamItem(const void* data,
