@@ -32,6 +32,7 @@
 #include "../Logging.h"
 #include "../OrthancException.h"
 #include "../TemporaryFile.h"
+#include "../SystemToolbox.h"
 #include "HttpToolbox.h"
 #include "IHttpHandler.h"
 #include "MultipartStreamReader.h"
@@ -119,12 +120,19 @@ namespace Orthanc
           {
             size_t packetSize = std::min(remainingSize, static_cast<size_t>(INT_MAX));
 
-            int status = mg_write(connection_, &(reinterpret_cast<const char*>(buffer)[offset]), packetSize);  
-
-            if (status != static_cast<int>(packetSize))
+            // note: mg_write may sometimes only send a part of the buffer e.g. when the OS is not able to send the full buffer -> we might need to iterate a few times
+            size_t totalSent = 0;
+            while (totalSent < packetSize)
             {
-              // status == 0 when the connection has been closed, -1 on error
-              throw OrthancException(ErrorCode_NetworkProtocol);
+              int status = mg_write(connection_, &(reinterpret_cast<const char*>(buffer)[offset + totalSent]), packetSize - totalSent);
+
+              if (status <= 0)
+              {
+                // status == 0 when the connection has been closed, -1 on error
+                throw OrthancException(ErrorCode_NetworkProtocol);
+              }
+
+              totalSent += status;
             }
 
             offset += packetSize;
@@ -1568,7 +1576,7 @@ namespace Orthanc
         catch (boost::filesystem::filesystem_error& e)
         {
           throw OrthancException(ErrorCode_InternalError,
-                                 "Error while accessing the filesystem: " + e.path1().string());
+                                 "Error while accessing the filesystem: " + SystemToolbox::PathToUtf8(e.path1()));
         }
         catch (std::runtime_error&)
         {
@@ -1724,6 +1732,11 @@ namespace Orthanc
     return port_;
   }
 
+  void HttpServer::SetBindAddresses(const std::set<std::string>& bindAddresses)
+  {
+    bindAddresses_ = bindAddresses;
+  }
+
   void HttpServer::Start()
   {
     // reset thread counter used to generate HTTP thread names.
@@ -1750,11 +1763,28 @@ namespace Orthanc
         port += "s";
       }
 
+      std::string listeningPorts;
+      if (bindAddresses_.size() == 0) // default behaviour till 1.12.9 and when no "HttpBindAddresses" configurations are provided
+      {
+        listeningPorts = port;
+      }
+      else
+      {
+        std::set<std::string> addresses;
+        for (std::set<std::string>::const_iterator it = bindAddresses_.begin(); it != bindAddresses_.end(); ++it)
+        {
+          addresses.insert(*it + ":" + port);
+        }
+
+        Toolbox::JoinStrings(listeningPorts, addresses, ",");
+      }
+
+      std::list<std::string> dynamicStrings;
       std::vector<const char*> options;
 
       // Set the TCP port for the HTTP server
       options.push_back("listening_ports");
-      options.push_back(port.c_str());
+      options.push_back(listeningPorts.c_str());
         
       // Optimization reported by Chris Hafey
       // https://groups.google.com/d/msg/orthanc-users/CKueKX0pJ9E/_UCbl8T-VjIJ
@@ -1798,8 +1828,9 @@ namespace Orthanc
       if (sslVerifyPeers_)
       {
         // Set the trusted client certificates (for X509 mutual authentication)
+        dynamicStrings.push_back(SystemToolbox::PathToUtf8(trustedClientCertificates_));
         options.push_back("ssl_ca_file");
-        options.push_back(trustedClientCertificates_.c_str());
+        options.push_back(dynamicStrings.back().c_str());
       }
       
       if (ssl_)
@@ -1816,13 +1847,23 @@ namespace Orthanc
         }
 
         // Set the SSL certificate, if any
+        dynamicStrings.push_back(SystemToolbox::PathToUtf8(certificate_));
         options.push_back("ssl_certificate");
-        options.push_back(certificate_.c_str());
+        options.push_back(dynamicStrings.back().c_str());
       };
 
+      if (CIVETWEB_VERSION_MAJOR > 1 ||
+          (CIVETWEB_VERSION_MAJOR == 1 &&
+           CIVETWEB_VERSION_MINOR >= 15))
+      {
+        // URI-decoding of GET arguments was the default in civetweb <= 1.14
+        options.push_back("decode_query_string");
+        options.push_back("yes");
+      }
+
       assert(options.size() % 2 == 0);
       options.push_back(NULL);
-      
+
 #if MONGOOSE_USE_CALLBACKS == 0
       pimpl_->context_ = mg_start(&Callback, this, &options[0]);
 
@@ -1864,8 +1905,23 @@ namespace Orthanc
         }
         else
         {
+          std::string errorMsgDetails;
+          if (bindAddresses_.empty())
+          {
+            errorMsgDetails = "port " + port;
+          }
+          else
+          {
+            errorMsgDetails = listeningPorts;
+          }
+          
+          if (errno != 0) // there might be additionnal details about the error in errno
+          {
+            errorMsgDetails += ", errno = " + boost::lexical_cast<std::string>(errno) + ", " + strerror(errno);
+          }
+
           throw OrthancException(ErrorCode_HttpPortInUse,
-                                 " (port = " + boost::lexical_cast<std::string>(port_) + ")");
+                                 " (" + errorMsgDetails + ")");
         }
       }
 
@@ -1877,7 +1933,7 @@ namespace Orthanc
       }
 #endif
 
-      CLOG(WARNING, HTTP) << "HTTP server listening on port: " << GetPortNumber()
+      CLOG(WARNING, HTTP) << "HTTP server listening on" << (bindAddresses_.empty() ? " port: " + port : ": " + listeningPorts)
                           << " (HTTPS encryption is "
                           << (IsSslEnabled() ? "enabled" : "disabled")
                           << ", remote access is "
@@ -1915,9 +1971,22 @@ namespace Orthanc
   void HttpServer::RegisterUser(const char* username,
                                 const char* password)
   {
+    const std::string s(username);
+    if (s.find(':') != std::string::npos)
+    {
+      /**
+       * "A user-id containing a colon character is invalid, as the
+       * first colon in a user-pass string separates user-id and
+       * password from one another" (cf. issue 252)
+       * https://datatracker.ietf.org/doc/html/rfc7617
+       **/
+      throw OrthancException(ErrorCode_ParameterOutOfRange, "Usernames for HTTP Basic Authentication "
+                             "cannot contain \":\", but found: \"" + s + "\"");
+    }
+
     Stop();
 
-    std::string tag = std::string(username) + ":" + std::string(password);
+    std::string tag = s + ":" + std::string(password);
     std::string encoded;
     Toolbox::EncodeBase64(encoded, tag);
     registeredUsers_.insert(encoded);
@@ -2060,7 +2129,7 @@ namespace Orthanc
 #endif
   }
 
-  const std::string &HttpServer::GetSslCertificate() const
+  const boost::filesystem::path& HttpServer::GetSslCertificate() const
   {
     return certificate_;
   }
@@ -2077,7 +2146,7 @@ namespace Orthanc
     return ssl_;
   }
 
-  void HttpServer::SetSslCertificate(const char* path)
+  void HttpServer::SetSslCertificate(const boost::filesystem::path& path)
   {
     Stop();
     certificate_ = path;
@@ -2088,7 +2157,7 @@ namespace Orthanc
     return remoteAllowed_;
   }
 
-  void HttpServer::SetSslTrustedClientCertificates(const char* path)
+  void HttpServer::SetSslTrustedClientCertificates(const boost::filesystem::path &path)
   {
     Stop();
     trustedClientCertificates_ = path;
