@@ -1224,7 +1224,7 @@ namespace Orthanc
     for (unsigned int y = 0; y < height; y++)
     {
       uint8_t* q = reinterpret_cast<uint8_t*>(image.GetRow(y));
-      uint8_t* a = reinterpret_cast<uint8_t*>(alpha.GetRow(y));
+      const uint8_t* a = reinterpret_cast<uint8_t*>(alpha.GetRow(y));
 
       for (unsigned int x = 0; x < width; x++)
       {
@@ -2161,7 +2161,7 @@ namespace Orthanc
           PolygonEdge edge(v1, v2, GetPolygonNextY(points, i));
           globalEdgeTable[v1.GetY()].push_back(edge);
         }
-        else if (v1.GetY() > v2.GetY())
+        else
         {
           // Down-going edge
           PolygonEdge edge(v2, v1, yPrev);
@@ -2789,6 +2789,19 @@ namespace Orthanc
         }
         break;
 
+      case PixelFormat_Grayscale16:
+        if (useRound)
+        {
+          SeparableConvolutionFloat<uint16_t, 1u, true>
+            (image, horizontal, horizontalAnchor, vertical, verticalAnchor, normalization);
+        }
+        else
+        {
+          SeparableConvolutionFloat<uint16_t, 1u, false>
+            (image, horizontal, horizontalAnchor, vertical, verticalAnchor, normalization);
+        }
+        break;
+
       case PixelFormat_RGB24:
         if (useRound)
         {
@@ -2822,6 +2835,14 @@ namespace Orthanc
   }
 
 
+  void ImageProcessing::MeanFilter(ImageAccessor& image, size_t horizontalKernelWidth, size_t verticalKernelWidth)
+  {
+    std::vector<float> hKernel(horizontalKernelWidth, 1.0f);
+    std::vector<float> vKernel(verticalKernelWidth, 1.0f);
+    
+    SeparableConvolution(image, hKernel, horizontalKernelWidth / 2, vKernel, verticalKernelWidth / 2, false);
+  }
+
   void ImageProcessing::FitSize(ImageAccessor& target,
                                 const ImageAccessor& source)
   {
