@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -26,6 +26,7 @@
 
 #include "../OrthancFramework.h"
 
+#include "../DicomFormat/DicomImageInformation.h"
 #include "ImageAccessor.h"
 
 #include <vector>
@@ -200,6 +201,8 @@ namespace Orthanc
     static void SmoothGaussian5x5(ImageAccessor& image,
                                   bool useRound /* this is expensive */);
 
+    static void MeanFilter(ImageAccessor& image, size_t horizontalAverageWidth, size_t verticalAverageWidth);
+
     static void FitSize(ImageAccessor& target,
                         const ImageAccessor& source);
 
@@ -222,5 +225,14 @@ namespace Orthanc
 
     static void Maximum(ImageAccessor& image /* inout */,
                         const ImageAccessor& other);
+
+    static void Render(ImageAccessor& target,
+                       const DicomImageInformation& info,
+                       const ImageAccessor& source,
+                       const Window& window);
+
+    static void RenderDefaultWindow(ImageAccessor& target,
+                                    const DicomImageInformation& info,
+                                    const ImageAccessor& source);
   };
 }
