@@ -207,8 +207,17 @@ namespace Orthanc
     if (enforceAligned_)
     {
       if (alignedImageBuffer_ != NULL)
+      {
         free(alignedImageBuffer_);
+      }
+
       alignedImageBuffer_ = malloc(pitch * height);
+      
+      if (alignedImageBuffer_ == NULL)
+      {
+        throw OrthancException(ErrorCode_NotEnoughMemory);
+      }
+      
       memcpy(alignedImageBuffer_, &content_[offset], pitch* height);
       content_ = "";
       AssignWritable(format, width, height, pitch, alignedImageBuffer_);
@@ -272,7 +281,7 @@ namespace Orthanc
 
   
 #if ORTHANC_SANDBOXED == 0
-  void PamReader::ReadFromFile(const std::string& filename)
+  void PamReader::ReadFromFile(const boost::filesystem::path& filename)
   {
     SystemToolbox::ReadFile(content_, filename);
     ParseContent();
