@@ -44,6 +44,11 @@
 #  error The macro ORTHANC_SANDBOXED must be defined
 #endif
 
+#if ORTHANC_SANDBOXED != 1
+#include <boost/filesystem.hpp>
+#endif
+
+
 namespace Orthanc
 {
   class ORTHANC_PUBLIC PngReader : public ImageAccessor
@@ -61,7 +66,7 @@ namespace Orthanc
     PngReader();
 
 #if ORTHANC_SANDBOXED == 0
-    void ReadFromFile(const std::string& filename);
+    void ReadFromFile(const boost::filesystem::path& filename);
 #endif
 
     void ReadFromMemory(const void* buffer,
