@@ -25,6 +25,7 @@
 #pragma once
 
 #include "IJob.h"
+#include "../OrthancException.h"  // For ErrorPayload
 
 namespace Orthanc
 {
@@ -39,6 +40,7 @@ namespace Orthanc
     bool           hasSerialized_;
     std::string    details_;
     Json::Value    userData_;
+    ErrorPayload   errorPayload_;
 
   public:
     JobStatus();
@@ -98,5 +100,15 @@ namespace Orthanc
     {
       return userData_;
     }
+
+    ErrorPayload& GetErrorPayload()
+    {
+      return errorPayload_;
+    }
+
+    const ErrorPayload& GetErrorPayload() const
+    {
+      return errorPayload_;
+    }
   };
 }
