@@ -68,11 +68,30 @@ namespace Orthanc
     return result;
   }
 
+  JobStepResult JobStepResult::Failure(const ErrorCode& error,
+                                       const char* details,
+                                       const ErrorPayload& payload)
+  {
+    JobStepResult result = Failure(error, details);
+    result.failurePayload_ = payload;
+
+    return result;
+  }
+
 
   JobStepResult JobStepResult::Failure(const OrthancException& exception)
   {
-    return Failure(exception.GetErrorCode(),
-                   exception.HasDetails() ? exception.GetDetails() : NULL);
+    if (exception.GetPayload().HasContent())
+    {
+      return Failure(exception.GetErrorCode(),
+                     exception.HasDetails() ? exception.GetDetails() : NULL,
+                     exception.GetPayload());
+    }
+    else
+    {
+      return Failure(exception.GetErrorCode(),
+                     exception.HasDetails() ? exception.GetDetails() : NULL);
+    }
   }
 
   JobStepCode JobStepResult::GetCode() const
