@@ -25,11 +25,14 @@
 #pragma once
 
 #include "../Enumerations.h"
+#include "../OrthancException.h"
+
+#include <boost/shared_ptr.hpp>
+#include <json/value.h>
+#include <stdint.h>
 
 namespace Orthanc
 {
-  class OrthancException;
-  
   class ORTHANC_PUBLIC JobStepResult
   {
   private:
@@ -37,6 +40,7 @@ namespace Orthanc
     unsigned int  timeout_;
     ErrorCode     error_;
     std::string   failureDetails_;
+    ErrorPayload  failurePayload_;
     
     explicit JobStepResult(JobStepCode code) :
       code_(code),
@@ -57,6 +61,10 @@ namespace Orthanc
     static JobStepResult Failure(const ErrorCode& error,
                                  const char* details);
 
+    static JobStepResult Failure(const ErrorCode& error,
+                                 const char* details,
+                                 const ErrorPayload& payload);
+
     static JobStepResult Failure(const OrthancException& exception);
 
     JobStepCode GetCode() const;
@@ -66,5 +74,10 @@ namespace Orthanc
     ErrorCode GetFailureCode() const;
 
     const std::string& GetFailureDetails() const;
+
+    const ErrorPayload& GetFailurePayload() const
+    {
+      return failurePayload_;
+    }
   };
 }
