@@ -44,6 +44,8 @@ namespace Orthanc
   static const char* ERROR_CODE = "ErrorCode";
   static const char* ERROR_DETAILS = "ErrorDetails";
   static const char* USER_DATA = "UserData";
+  static const char* ERROR_PAYLOAD_TYPE = "ErrorPayloadType";
+  static const char* ERROR_PAYLOAD = "ErrorPayload";
 
 
   class JobsRegistry::JobHandler : public boost::noncopyable
@@ -304,6 +306,12 @@ namespace Orthanc
           target[USER_DATA] = userData;
         }
         
+        if (lastStatus_.GetErrorPayload().HasContent())
+        {
+          target[ERROR_PAYLOAD_TYPE] = lastStatus_.GetErrorPayload().GetType();
+          target[ERROR_PAYLOAD] = lastStatus_.GetErrorPayload().GetContent();
+        }
+
         return true;
       }
       else
@@ -333,7 +341,6 @@ namespace Orthanc
 
       job_.reset(unserializer.UnserializeJob(serialized[JOB]));
       job_->GetJobType(jobType_);
-      job_->Start();
 
       ErrorCode errorCode;
       if (serialized.isMember(ERROR_CODE))
@@ -351,13 +358,27 @@ namespace Orthanc
         details = SerializationToolbox::ReadString(serialized, ERROR_DETAILS);
       }
 
+      if (serialized.isMember(USER_DATA))
+      {
+        job_->SetUserData(serialized[USER_DATA]);
+      }
+
       lastStatus_ = JobStatus(errorCode, details, *job_);
+
+      if (serialized.isMember(ERROR_PAYLOAD_TYPE) &&
+          serialized.isMember(ERROR_PAYLOAD))
+      {
+        const std::string type = SerializationToolbox::ReadString(serialized, ERROR_PAYLOAD_TYPE);
+        lastStatus_.GetErrorPayload().SetContent(StringToErrorPayloadType(type), serialized[ERROR_PAYLOAD]);
+      }
+
+      job_->Start();
     }
   };
 
 
-  bool JobsRegistry::PriorityComparator::operator() (JobHandler* const& a,
-                                                     JobHandler* const& b) const
+  bool JobsRegistry::PriorityComparator::operator() (const JobHandler* const& a,
+                                                     const JobHandler* const& b) const
   {
     return a->GetPriority() < b->GetPriority();
   }
@@ -385,7 +406,7 @@ namespace Orthanc
     return false;
   }
 
-  bool JobsRegistry::IsCompletedJob(JobHandler& job) const
+  bool JobsRegistry::IsCompletedJob(const JobHandler& job) const
   {
     for (CompletedJobs::const_iterator it = completedJobs_.begin();
          it != completedJobs_.end(); ++it)
@@ -876,14 +897,26 @@ namespace Orthanc
           {
             ErrorCode code = it->second->GetLastStatus().GetErrorCode();
             const std::string& details = it->second->GetLastStatus().GetDetails();
+            
+            // Prefer the error payload from the job level if there is one since it should contain more information than the step error payload.
+            ErrorPayload jobErrorPayload;
+            it->second->GetJob().LookupErrorPayload(jobErrorPayload);
 
-            if (details.empty())
+            if (jobErrorPayload.HasContent())
             {
-              throw OrthancException(code);
+              throw OrthancException(code, details).SetPayload(jobErrorPayload);
+            }
+            else if (it->second->GetLastStatus().GetErrorPayload().HasContent())
+            {
+              throw OrthancException(code, details).SetPayload(it->second->GetLastStatus().GetErrorPayload());
+            }
+            else if (!details.empty())
+            {
+              throw OrthancException(code, details);
             }
             else
             {
-              throw OrthancException(code, details);
+              throw OrthancException(code);
             }
           }
           else
@@ -895,12 +928,7 @@ namespace Orthanc
         {
           // Success, try and retrieve the status of the job
           JobsIndex::const_iterator it = jobsIndex_.find(id);
-          if (it == jobsIndex_.end())
-          {
-            // Should not happen
-            state = JobState_Failure;
-          }
-          else
+          if (it != jobsIndex_.end())
           {
             const JobStatus& status = it->second->GetLastStatus();
             successContent = status.GetPublicContent();
@@ -1272,27 +1300,35 @@ namespace Orthanc
     {
       boost::mutex::scoped_lock lock(registry_.mutex_);
 
-      switch (targetState_)
+      try
       {
-        case JobState_Failure:
-          registry_.MarkRunningAsCompleted
-            (*handler_, canceled_ ? CompletedReason_Canceled : CompletedReason_Failure);
-          break;
+        switch (targetState_)
+        {
+          case JobState_Failure:
+            registry_.MarkRunningAsCompleted
+              (*handler_, canceled_ ? CompletedReason_Canceled : CompletedReason_Failure);
+            break;
 
-        case JobState_Success:
-          registry_.MarkRunningAsCompleted(*handler_, CompletedReason_Success);
-          break;
+          case JobState_Success:
+            registry_.MarkRunningAsCompleted(*handler_, CompletedReason_Success);
+            break;
 
-        case JobState_Paused:
-          registry_.MarkRunningAsPaused(*handler_);
-          break;
+          case JobState_Paused:
+            registry_.MarkRunningAsPaused(*handler_);
+            break;
 
-        case JobState_Retry:
-          registry_.MarkRunningAsRetry(*handler_, targetRetryTimeout_);
-          break;
+          case JobState_Retry:
+            registry_.MarkRunningAsRetry(*handler_, targetRetryTimeout_);
+            break;
 
-        default:
-          assert(0);
+          default:
+            assert(0);
+        }
+      }
+      catch (OrthancException& e)
+      {
+        // Don't throw exceptions in destructors
+        LOG(ERROR) << "Exception in destructor: " << e.What();
       }
     }
   }
@@ -1445,6 +1481,28 @@ namespace Orthanc
   }
 
 
+  void JobsRegistry::RunningJob::UpdateStatus(ErrorCode code,
+                                              const std::string& details,
+                                              const ErrorPayload& errorPayload)
+  {
+    if (!IsValid())
+    {
+      throw OrthancException(ErrorCode_BadSequenceOfCalls);
+    }
+    else
+    {
+      JobStatus status(code, details, *job_);
+      status.GetErrorPayload() = errorPayload;
+
+      boost::mutex::scoped_lock lock(registry_.mutex_);
+      registry_.CheckInvariants();
+      assert(handler_->GetState() == JobState_Running);
+
+      handler_->SetLastStatus(status);
+    }
+  }
+
+
   void JobsRegistry::RunningJob::UpdateStatus(ErrorCode code,
                                               const std::string& details)
   {
@@ -1553,7 +1611,7 @@ namespace Orthanc
     for (JobsIndex::const_iterator it = jobsIndex_.begin();
          it != jobsIndex_.end(); ++it)
     {
-      JobHandler& job = *it->second;
+      const JobHandler& job = *it->second;
 
       switch (job.GetState())
       {
