@@ -28,6 +28,7 @@
 #include "IJobOperation.h"
 
 #include "../../Compatibility.h"  // For ORTHANC_OVERRIDE
+#include "../../OrthancException.h"
 
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/condition_variable.hpp>
@@ -69,7 +70,7 @@ namespace Orthanc
     SequenceOfOperationsJob(IJobUnserializer& unserializer,
                             const Json::Value& serialized);
 
-    virtual ~SequenceOfOperationsJob();
+    virtual ~SequenceOfOperationsJob() ORTHANC_OVERRIDE;
 
     void SetDescription(const std::string& description);
 
@@ -140,9 +141,18 @@ namespace Orthanc
 
     void AwakeTrailingSleep();
 
+    virtual void SetUserData(const Json::Value& userData) ORTHANC_OVERRIDE
+    {
+      throw OrthancException(ErrorCode_NotImplemented);
+    }
+
     virtual bool GetUserData(Json::Value& userData) const ORTHANC_OVERRIDE
     {
       return false;
     }
+
+    virtual void LookupErrorPayload(ErrorPayload& payload) const ORTHANC_OVERRIDE
+    {
+    }
   };
 }
