@@ -71,7 +71,7 @@ namespace Orthanc
     SetOfCommandsJob(ICommandUnserializer* unserializer  /* takes ownership */,
                      const Json::Value& source);
 
-    virtual ~SetOfCommandsJob();
+    virtual ~SetOfCommandsJob() ORTHANC_OVERRIDE;
 
     size_t GetPosition() const;
 
@@ -79,7 +79,7 @@ namespace Orthanc
 
     const std::string& GetDescription() const;
 
-    void Reserve(size_t size);
+    virtual void Reserve(size_t size);
 
     size_t GetCommandsCount() const;
 
@@ -118,7 +118,7 @@ namespace Orthanc
       return false;
     }
 
-    void SetUserData(const Json::Value& userData)
+    virtual void SetUserData(const Json::Value& userData) ORTHANC_OVERRIDE
     {
       userData_ = userData;
     }
@@ -133,5 +133,8 @@ namespace Orthanc
       return false;
     }
 
+    virtual void LookupErrorPayload(ErrorPayload& payload) const ORTHANC_OVERRIDE
+    {
+    }
   };
 }
