@@ -45,10 +45,7 @@ namespace Orthanc
   public:
     MallocMemoryBuffer();
 
-    virtual ~MallocMemoryBuffer()
-    {
-      Clear();
-    }
+    virtual ~MallocMemoryBuffer() ORTHANC_OVERRIDE;
 
     void Clear();
 
