@@ -25,16 +25,13 @@
 #pragma once
 
 #include "../IDynamicObject.h"
+#include "../Compatibility.h"
 
 namespace Orthanc
 {
   class IRunnableBySteps : public IDynamicObject
   {
   public:
-    virtual ~IRunnableBySteps()
-    {
-    }
-
     // Must return "true" if the runnable wishes to continue. Must
     // return "false" if the runnable has not finished its job.
     virtual bool Step() = 0;
