@@ -26,6 +26,8 @@
 
 #include "IRunnableBySteps.h"
 
+#include "../MetricsRegistry.h"
+
 #include <boost/shared_ptr.hpp>
 
 namespace Orthanc
@@ -36,10 +38,18 @@ namespace Orthanc
     struct PImpl;
     boost::shared_ptr<PImpl> pimpl_;
 
-    void Stop();
+    void Start(size_t countWorkers,
+               const std::string& baseThreadName,
+               MetricsRegistry::SharedMetrics* availableWorkers /* can be NULL */);
 
   public:
-    explicit RunnableWorkersPool(size_t countWorkers, const std::string& name);
+    RunnableWorkersPool(size_t countWorkers,
+                        const std::string& baseThreadName);
+
+    RunnableWorkersPool(size_t countWorkers,
+                        const std::string& name,
+                        MetricsRegistry& registry,
+                        const char* availableWorkersMetricsName);
 
     ~RunnableWorkersPool();
 
