@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -169,9 +169,9 @@ namespace Orthanc
   }
 
 
-  void RestApiHierarchy::DeleteChildren(Children& children)
+  void RestApiHierarchy::DeleteChildren(const Children& children)
   {
-    for (Children::iterator it = children.begin();
+    for (Children::const_iterator it = children.begin();
          it != children.end(); ++it)
     {
       delete it->second;
