@@ -59,7 +59,7 @@ TEST(FilesystemStorage, Basic)
 
   std::string data = Toolbox::GenerateUuid();
   std::string uid = Toolbox::GenerateUuid();
-  s.Create(uid.c_str(), &data[0], data.size(), FileContentType_Unknown);
+  s.Create(uid, &data[0], data.size(), FileContentType_Unknown);
   std::string d;
   {
     std::unique_ptr<IMemoryBuffer> buffer(s.ReadWhole(uid, FileContentType_Unknown));
@@ -83,7 +83,7 @@ TEST(FilesystemStorage, Basic2)
   std::vector<uint8_t> data;
   StringToVector(data, Toolbox::GenerateUuid());
   std::string uid = Toolbox::GenerateUuid();
-  s.Create(uid.c_str(), &data[0], data.size(), FileContentType_Unknown);
+  s.Create(uid, &data[0], data.size(), FileContentType_Unknown);
   std::string d;
   {
     std::unique_ptr<IMemoryBuffer> buffer(s.ReadWhole(uid, FileContentType_Unknown));
@@ -108,7 +108,7 @@ TEST(FilesystemStorage, FileWithSameNameAsTopDirectory)
   std::vector<uint8_t> data;
   StringToVector(data, Toolbox::GenerateUuid());
 
-  SystemToolbox::WriteFile("toto", "UnitTestsStorageTop/12");
+  SystemToolbox::WriteFile("toto", SystemToolbox::PathFromUtf8("UnitTestsStorageTop/12"));
   ASSERT_THROW(s.Create("12345678-1234-1234-1234-1234567890ab", &data[0], data.size(), FileContentType_Unknown), OrthancException);
   s.Clear();
 }
@@ -121,8 +121,8 @@ TEST(FilesystemStorage, FileWithSameNameAsChildDirectory)
   std::vector<uint8_t> data;
   StringToVector(data, Toolbox::GenerateUuid());
 
-  SystemToolbox::MakeDirectory("UnitTestsStorageChild/12");
-  SystemToolbox::WriteFile("toto", "UnitTestsStorageChild/12/34");
+  SystemToolbox::MakeDirectory(SystemToolbox::PathFromUtf8("UnitTestsStorageChild/12"));
+  SystemToolbox::WriteFile("toto", SystemToolbox::PathFromUtf8("UnitTestsStorageChild/12/34"));
   ASSERT_THROW(s.Create("12345678-1234-1234-1234-1234567890ab", &data[0], data.size(), FileContentType_Unknown), OrthancException);
   s.Clear();
 }
@@ -135,12 +135,27 @@ TEST(FilesystemStorage, FileAlreadyExists)
   std::vector<uint8_t> data;
   StringToVector(data, Toolbox::GenerateUuid());
 
-  SystemToolbox::MakeDirectory("UnitTestsStorageFileAlreadyExists/12/34");
-  SystemToolbox::WriteFile("toto", "UnitTestsStorageFileAlreadyExists/12/34/12345678-1234-1234-1234-1234567890ab");
+  SystemToolbox::MakeDirectory(SystemToolbox::PathFromUtf8("UnitTestsStorageFileAlreadyExists/12/34"));
+  SystemToolbox::WriteFile("toto", SystemToolbox::PathFromUtf8("UnitTestsStorageFileAlreadyExists/12/34/12345678-1234-1234-1234-1234567890ab"));
   ASSERT_THROW(s.Create("12345678-1234-1234-1234-1234567890ab", &data[0], data.size(), FileContentType_Unknown), OrthancException);
   s.Clear();
 }
 
+#if !defined(__MINGW32__)  // non-ASCII paths are not supported when built with mingw
+TEST(FilesystemStorage, FileAlreadyExistsUtf8)
+{
+  FilesystemStorage s(SystemToolbox::PathFromUtf8("\xd0\x95UnitTestsStorageFileAlreadyExists"));
+  s.Clear();
+
+  std::vector<uint8_t> data;
+  StringToVector(data, Toolbox::GenerateUuid());
+
+  SystemToolbox::MakeDirectory(SystemToolbox::PathFromUtf8("\xd0\x95UnitTestsStorageFileAlreadyExists/12/34"));
+  SystemToolbox::WriteFile("toto", SystemToolbox::PathFromUtf8("\xd0\x95UnitTestsStorageFileAlreadyExists/12/34/12345678-1234-1234-1234-1234567890ab"));
+  ASSERT_THROW(s.Create("12345678-1234-1234-1234-1234567890ab", &data[0], data.size(), FileContentType_Unknown), OrthancException);
+  s.Clear();
+}
+#endif
 
 TEST(FilesystemStorage, EndToEnd)
 {
@@ -152,7 +167,7 @@ TEST(FilesystemStorage, EndToEnd)
   {
     std::string t = Toolbox::GenerateUuid();
     std::string uid = Toolbox::GenerateUuid();
-    s.Create(uid.c_str(), &t[0], t.size(), FileContentType_Unknown);
+    s.Create(uid, &t[0], t.size(), FileContentType_Unknown);
     u.push_back(uid);
   }
 
@@ -339,4 +354,46 @@ TEST(StorageAccessor, Range)
     ASSERT_EQ("o", s);
     ASSERT_THROW(StorageAccessor::Range::ParseHttpRange("bytes=5-").Extract(s, "Hello"), OrthancException);
   }
-}
\ No newline at end of file
+}
+
+
+TEST(SystemToolbox, ReadRange)
+{
+  const boost::filesystem::path path(SystemToolbox::PathFromUtf8("UnitTestsResults/hello.txt"));
+  SystemToolbox::WriteFile("abc", path);
+
+  std::string s;
+  SystemToolbox::ReadFileRange(s, path, 0, 1, true);
+  ASSERT_EQ(1u, s.size());
+  ASSERT_EQ('a', s[0]);
+
+  SystemToolbox::ReadFileRange(s, path, 1, 2, true);
+  ASSERT_EQ(1u, s.size());
+  ASSERT_EQ('b', s[0]);
+
+  SystemToolbox::ReadFileRange(s, path, 2, 3, true);
+  ASSERT_EQ(1u, s.size());
+  ASSERT_EQ('c', s[0]);
+
+  ASSERT_THROW(SystemToolbox::ReadFileRange(s, path, 3, 4, true), OrthancException);
+
+  SystemToolbox::ReadFileRange(s, path, 0, 2, true);
+  ASSERT_EQ(2u, s.size());
+  ASSERT_EQ('a', s[0]);
+  ASSERT_EQ('b', s[1]);
+
+  SystemToolbox::ReadFileRange(s, path, 1, 3, true);
+  ASSERT_EQ(2u, s.size());
+  ASSERT_EQ('b', s[0]);
+  ASSERT_EQ('c', s[1]);
+
+  ASSERT_THROW(SystemToolbox::ReadFileRange(s, path, 2, 4, true), OrthancException);
+
+  SystemToolbox::ReadFileRange(s, path, 0, 3, true);
+  ASSERT_EQ(3u, s.size());
+  ASSERT_EQ('a', s[0]);
+  ASSERT_EQ('b', s[1]);
+  ASSERT_EQ('c', s[2]);
+
+  ASSERT_THROW(SystemToolbox::ReadFileRange(s, path, 1, 4, true), OrthancException);
+}
