@@ -46,10 +46,11 @@
 #  include "../Sources/MetricsRegistry.h"
 #  include "../Sources/SystemToolbox.h"
 #  include "../Sources/TemporaryFile.h"
+
+#  include <boost/thread.hpp>
 #endif
 
 #include <ctype.h>
-#include <boost/thread.hpp>
 
 
 using namespace Orthanc;
@@ -369,6 +370,9 @@ TEST(Uri, AutodetectMimeType)
   ASSERT_STREQ("model/obj", EnumerationToString(SystemToolbox::AutodetectMimeType(".obj")));
   ASSERT_STREQ("model/mtl", EnumerationToString(SystemToolbox::AutodetectMimeType(".mtl")));
   ASSERT_STREQ("model/stl", EnumerationToString(SystemToolbox::AutodetectMimeType(".stl")));
+
+  // test with utf8 strings
+  ASSERT_STREQ("model/stl", EnumerationToString(SystemToolbox::AutodetectMimeType("\xd0\x94.stl")));
 }
 #endif
 
@@ -496,7 +500,7 @@ TEST(Toolbox, ConvertFromLatin1)
   // This is a Latin-1 test string
   const unsigned char data[10] = { 0xe0, 0xe9, 0xea, 0xe7, 0x26, 0xc6, 0x61, 0x62, 0x63, 0x00 };
   
-  std::string s((char*) &data[0], 10);
+  std::string s(reinterpret_cast<const char*>(&data[0]), 10);
   ASSERT_EQ("&abc", Toolbox::ConvertToAscii(s));
 
   // Open in Emacs, then save with UTF-8 encoding, then "hexdump -C"
@@ -525,7 +529,7 @@ TEST(Toolbox, FixUtf8)
   // This is a Latin-1 test string: "crane" with a circumflex accent
   const unsigned char latin1[] = { 0x63, 0x72, 0xe2, 0x6e, 0x65 };
 
-  std::string s((char*) &latin1[0], sizeof(latin1) / sizeof(char));
+  std::string s(reinterpret_cast<const char*>(&latin1[0]), sizeof(latin1) / sizeof(char));
 
   ASSERT_EQ(s, Toolbox::ConvertFromUtf8(Toolbox::ConvertToUtf8(s, Encoding_Latin1, false, false), Encoding_Latin1));
   ASSERT_EQ("cre", Toolbox::ConvertToUtf8(s, Encoding_Utf8, false, false));
@@ -536,7 +540,7 @@ static int32_t GetUnicode(const uint8_t* data,
                           size_t size,
                           size_t expectedLength)
 {
-  std::string s((char*) &data[0], size);
+  std::string s(reinterpret_cast<const char*>(&data[0]), size);
   uint32_t unicode;
   size_t length;
   Toolbox::Utf8ToUnicodeCharacter(unicode, length, s, 0);
@@ -639,8 +643,8 @@ TEST(Toolbox, IsAsciiString)
 #if defined(__linux__)
 TEST(Toolbox, AbsoluteDirectory)
 {
-  ASSERT_EQ("/tmp/hello", SystemToolbox::InterpretRelativePath("/tmp", "hello"));
-  ASSERT_EQ("/tmp", SystemToolbox::InterpretRelativePath("/tmp", "/tmp"));
+  ASSERT_EQ("/tmp/hello", SystemToolbox::PathToUtf8(SystemToolbox::InterpretRelativePath("/tmp", "hello")));
+  ASSERT_EQ("/tmp", SystemToolbox::PathToUtf8(SystemToolbox::InterpretRelativePath("/tmp", "/tmp")));
 }
 #endif
 
@@ -648,7 +652,7 @@ TEST(Toolbox, AbsoluteDirectory)
 #if ORTHANC_SANDBOXED != 1
 TEST(Toolbox, WriteFile)
 {
-  std::string path;
+  boost::filesystem::path path;
 
   {
     TemporaryFile tmp;
@@ -660,33 +664,33 @@ TEST(Toolbox, WriteFile)
     s.append("World");
     ASSERT_EQ(11u, s.size());
 
-    SystemToolbox::WriteFile(s, path.c_str());
+    SystemToolbox::WriteFile(s, path);
 
     std::string t;
-    SystemToolbox::ReadFile(t, path.c_str());
+    SystemToolbox::ReadFile(t, path);
 
     ASSERT_EQ(11u, t.size());
     ASSERT_EQ(0, t[5]);
     ASSERT_EQ(0, memcmp(s.c_str(), t.c_str(), s.size()));
 
     std::string h;
-    ASSERT_EQ(true, SystemToolbox::ReadHeader(h, path.c_str(), 1));
+    ASSERT_EQ(true, SystemToolbox::ReadHeader(h, path, 1));
     ASSERT_EQ(1u, h.size());
     ASSERT_EQ('H', h[0]);
-    ASSERT_TRUE(SystemToolbox::ReadHeader(h, path.c_str(), 0));
+    ASSERT_TRUE(SystemToolbox::ReadHeader(h, path, 0));
     ASSERT_EQ(0u, h.size());
-    ASSERT_FALSE(SystemToolbox::ReadHeader(h, path.c_str(), 32));
+    ASSERT_FALSE(SystemToolbox::ReadHeader(h, path, 32));
     ASSERT_EQ(11u, h.size());
     ASSERT_EQ(0, memcmp(s.c_str(), h.c_str(), s.size()));
   }
 
   std::string u;
-  ASSERT_THROW(SystemToolbox::ReadFile(u, path.c_str()), OrthancException);
+  ASSERT_THROW(SystemToolbox::ReadFile(u, path), OrthancException);
 
   {
     TemporaryFile tmp;
     std::string s = "Hello";
-    SystemToolbox::WriteFile(s, tmp.GetPath(), true /* call fsync() */);
+    SystemToolbox::WriteFile(s.c_str(), s.size(), tmp.GetPath(), true /* call fsync() */);
     std::string t;
     SystemToolbox::ReadFile(t, tmp.GetPath());
     ASSERT_EQ(s, t);
@@ -1790,3 +1794,64 @@ TEST(Toolbox, IsVersionAbove)
   ASSERT_FALSE(Toolbox::IsVersionAbove("18.19.20", 18, 20, 0));
   ASSERT_FALSE(Toolbox::IsVersionAbove("18.19.20", 19, 0, 0));
 }
+
+
+TEST(OrthancException, ErrorPayload)
+{
+  ErrorPayload b;
+
+  {
+    ErrorPayload a;
+    ASSERT_THROW(a.SetContent(ErrorPayloadType_None, ""), OrthancException);
+    ASSERT_FALSE(a.HasContent());
+    ASSERT_THROW(a.GetType(), OrthancException);
+    ASSERT_THROW(a.GetContent(), OrthancException);
+
+    {
+      ErrorPayload c(a);
+      ASSERT_FALSE(c.HasContent());
+      ASSERT_THROW(c.GetType(), OrthancException);
+      ASSERT_THROW(c.GetContent(), OrthancException);
+    }
+
+    b = a;
+  }
+
+  ASSERT_FALSE(b.HasContent());
+  ASSERT_THROW(b.GetType(), OrthancException);
+  ASSERT_THROW(b.GetContent(), OrthancException);
+
+  {
+    ErrorPayload a;
+    a.SetContent(ErrorPayloadType_Dimse, "Hello");
+    ASSERT_TRUE(a.HasContent());
+    ASSERT_EQ(ErrorPayloadType_Dimse, a.GetType());
+    ASSERT_TRUE(a.GetContent().isString());
+    ASSERT_EQ("Hello", a.GetContent().asString());
+
+    {
+      ErrorPayload c(a);
+      ASSERT_TRUE(c.HasContent());
+      ASSERT_EQ(ErrorPayloadType_Dimse, c.GetType());
+      ASSERT_TRUE(c.GetContent().isString());
+      ASSERT_EQ("Hello", c.GetContent().asString());
+
+      c = ErrorPayload();
+      ASSERT_FALSE(c.HasContent());
+      ASSERT_THROW(c.GetType(), OrthancException);
+      ASSERT_THROW(c.GetContent(), OrthancException);
+    }
+
+    b = a;
+
+    a.ClearContent();
+    ASSERT_FALSE(a.HasContent());
+    ASSERT_THROW(a.GetType(), OrthancException);
+    ASSERT_THROW(a.GetContent(), OrthancException);
+  }
+
+  ASSERT_TRUE(b.HasContent());
+  ASSERT_EQ(ErrorPayloadType_Dimse, b.GetType());
+  ASSERT_TRUE(b.GetContent().isString());
+  ASSERT_EQ("Hello", b.GetContent().asString());
+}
