@@ -77,7 +77,7 @@ TEST(PngWriter, ColorPattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/ColorPattern.png", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/ColorPattern.png");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/ColorPattern.png"));
 #endif
 
   std::string md5;
@@ -137,7 +137,7 @@ TEST(PngWriter, Color16Pattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/Color16Pattern.png", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/Color16Pattern.png");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/Color16Pattern.png"));
 #endif
 
   std::string md5;
@@ -172,7 +172,7 @@ TEST(PngWriter, Gray8Pattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/Gray8Pattern.png", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/Gray8Pattern.png");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/Gray8Pattern.png"));
 #endif
 
   std::string md5;
@@ -208,7 +208,7 @@ TEST(PngWriter, Gray16Pattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/Gray16Pattern.png", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/Gray16Pattern.png");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/Gray16Pattern.png"));
 #endif
 
   std::string md5;
@@ -252,7 +252,7 @@ TEST(PngWriter, EndToEnd)
     v = 0;
     for (unsigned int y = 0; y < height; y++)
     {
-      const uint16_t *p = reinterpret_cast<const uint16_t*>((const uint8_t*) r.GetConstBuffer() + y * r.GetPitch());
+      const uint16_t *p = reinterpret_cast<const uint16_t*>(reinterpret_cast<const uint8_t*>(r.GetConstBuffer()) + y * r.GetPitch());
       ASSERT_EQ(p, r.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
@@ -276,7 +276,7 @@ TEST(PngWriter, EndToEnd)
     v = 0;
     for (unsigned int y = 0; y < height; y++)
     {
-      const uint16_t *p = reinterpret_cast<const uint16_t*>((const uint8_t*) r2.GetConstBuffer() + y * r2.GetPitch());
+      const uint16_t *p = reinterpret_cast<const uint16_t*>(reinterpret_cast<const uint8_t*>(r2.GetConstBuffer()) + y * r2.GetPitch());
       ASSERT_EQ(p, r2.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
@@ -310,10 +310,10 @@ TEST(JpegWriter, Basic)
 
 #if ORTHANC_SANDBOXED != 1
     Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/hello.jpg", img);
-    Orthanc::SystemToolbox::WriteFile(s, "UnitTestsResults/hello2.jpg");
+    Orthanc::SystemToolbox::WriteFile(s, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/hello2.jpg"));
 
     std::string t;
-    Orthanc::SystemToolbox::ReadFile(t, "UnitTestsResults/hello.jpg");
+    Orthanc::SystemToolbox::ReadFile(t, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/hello.jpg"));
     ASSERT_EQ(s.size(), t.size());
     ASSERT_EQ(0, memcmp(s.c_str(), t.c_str(), s.size()));
 #endif
@@ -327,7 +327,7 @@ TEST(JpegWriter, Basic)
 
 #if ORTHANC_SANDBOXED != 1
     Orthanc::JpegReader r2;
-    r2.ReadFromFile("UnitTestsResults/hello.jpg");
+    r2.ReadFromFile(Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/hello.jpg"));
     ASSERT_EQ(16u, r2.GetWidth());
     ASSERT_EQ(16u, r2.GetHeight());
 #endif
@@ -385,7 +385,7 @@ TEST(PamWriter, ColorPattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/ColorPattern.pam", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/ColorPattern.pam");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/ColorPattern.pam"));
 #endif
 
   std::string md5;
@@ -419,7 +419,7 @@ TEST(PamWriter, Gray8Pattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/Gray8Pattern.pam", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/Gray8Pattern.pam");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/Gray8Pattern.pam"));
 #endif
   
   std::string md5;
@@ -455,7 +455,7 @@ TEST(PamWriter, Gray16Pattern)
   Orthanc::IImageWriter::WriteToMemory(w, f, accessor);
 #else
   Orthanc::IImageWriter::WriteToFile(w, "UnitTestsResults/Gray16Pattern.pam", accessor);
-  Orthanc::SystemToolbox::ReadFile(f, "UnitTestsResults/Gray16Pattern.pam");
+  Orthanc::SystemToolbox::ReadFile(f, Orthanc::SystemToolbox::PathFromUtf8("UnitTestsResults/Gray16Pattern.pam"));
 #endif
 
   std::string md5;
@@ -500,7 +500,7 @@ TEST(PamWriter, EndToEnd)
     for (unsigned int y = 0; y < height; y++)
     {
       const uint16_t *p = reinterpret_cast<const uint16_t*>
-        ((const uint8_t*) r.GetConstBuffer() + y * r.GetPitch());
+        (reinterpret_cast<const uint8_t*>(r.GetConstBuffer()) + y * r.GetPitch());
       ASSERT_EQ(p, r.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
@@ -522,7 +522,7 @@ TEST(PamWriter, EndToEnd)
     for (unsigned int y = 0; y < height; y++)
     {
       const uint16_t* p = reinterpret_cast<const uint16_t*>
-        ((const uint8_t*)r.GetConstBuffer() + y * r.GetPitch());
+        (reinterpret_cast<const uint8_t*>(r.GetConstBuffer()) + y * r.GetPitch());
       ASSERT_EQ(p, r.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
@@ -547,7 +547,7 @@ TEST(PamWriter, EndToEnd)
     for (unsigned int y = 0; y < height; y++)
     {
       const uint16_t *p = reinterpret_cast<const uint16_t*>
-        ((const uint8_t*) r2.GetConstBuffer() + y * r2.GetPitch());
+        (reinterpret_cast<const uint8_t*>(r2.GetConstBuffer()) + y * r2.GetPitch());
       ASSERT_EQ(p, r2.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
@@ -574,7 +574,7 @@ TEST(PamWriter, EndToEnd)
     for (unsigned int y = 0; y < height; y++)
     {
       const uint16_t* p = reinterpret_cast<const uint16_t*>
-        ((const uint8_t*)r2.GetConstBuffer() + y * r2.GetPitch());
+        (reinterpret_cast<const uint8_t*>(r2.GetConstBuffer()) + y * r2.GetPitch());
       ASSERT_EQ(p, r2.GetConstRow(y));
       for (unsigned int x = 0; x < width; x++, p++, v++)
       {
