@@ -137,10 +137,20 @@ namespace
     {
       return false;
     }
+    
+    virtual void SetUserData(const Json::Value& userData) ORTHANC_OVERRIDE
+    {
+      throw OrthancException(ErrorCode_NotImplemented);
+    }
+
     virtual bool GetUserData(Json::Value& userData) const ORTHANC_OVERRIDE
     {
       return false;
     }
+
+    virtual void LookupErrorPayload(ErrorPayload& payload) const ORTHANC_OVERRIDE
+    {
+    }
   };
 
 
@@ -276,10 +286,10 @@ TEST(MultiThreading, SharedMessageQueueBasic)
 
 TEST(MultiThreading, SharedMessageQueueClean)
 {
-  std::set<int> s;
-
   try
   {
+    std::set<int> s;
+
     SharedMessageQueue q;
     q.Enqueue(new DynamicInteger(10, s));
     q.Enqueue(new DynamicInteger(20, s));  
@@ -727,25 +737,26 @@ TEST(JobsEngine, SubmitAndWait)
 }
 
 
-TEST(JobsEngine, DISABLED_SequenceOfOperationsJob)
+TEST(JobsEngine, SequenceOfOperationsJob)
 {
   JobsEngine engine(10);
   engine.SetThreadSleep(10);
   engine.SetWorkersCount(3);
   engine.Start();
 
-  std::string id;
-  SequenceOfOperationsJob* job = NULL;
-
   {
-    std::unique_ptr<SequenceOfOperationsJob> a(new SequenceOfOperationsJob);
-    job = a.get();
-    engine.GetRegistry().Submit(id, a.release(), 0);
+    std::string id;
+    std::unique_ptr<SequenceOfOperationsJob> seq(new SequenceOfOperationsJob);
+    engine.GetRegistry().Submit(id, seq.release(), 0);
   }
 
   boost::this_thread::sleep(boost::posix_time::milliseconds(500));
 
   {
+    SequenceOfOperationsJob* job = NULL;
+    std::unique_ptr<SequenceOfOperationsJob> seq(new SequenceOfOperationsJob);
+    job = seq.get();
+
     SequenceOfOperationsJob::Lock lock(*job);
     size_t i = lock.AddOperation(new LogJobOperation);
     size_t j = lock.AddOperation(new LogJobOperation);
@@ -1073,7 +1084,7 @@ TEST(JobsSerialization, DicomModification)
     modification.Remove(DICOM_TAG_SERIES_DESCRIPTION);
     modification.Replace(DICOM_TAG_PATIENT_NAME, "Test 4", true);
 
-    modification.Apply(*modified);
+    modification.Apply(modified);
 
     s = 42;
     modification.Serialize(s);
@@ -1084,7 +1095,7 @@ TEST(JobsSerialization, DicomModification)
     ASSERT_EQ(ResourceType_Series, modification.GetLevel());
     
     std::unique_ptr<ParsedDicomFile> second(source.Clone(true));
-    modification.Apply(*second);
+    modification.Apply(second);
 
     std::string t;
     ASSERT_TRUE(second->GetTagValue(t, DICOM_TAG_STUDY_DESCRIPTION));
@@ -1131,9 +1142,9 @@ TEST(JobsSerialization, DicomModification2)
 TEST(JobsSerialization, Registry)
 {   
   Json::Value s;
-  std::string i1, i2;
 
   {
+    std::string i1, i2;
     JobsRegistry registry(10);
     registry.Submit(i1, new DummyJob(), 10);
     registry.Submit(i2, new SequenceOfOperationsJob(), 30);
