@@ -38,7 +38,6 @@
 #include "../Sources/OrthancException.h"
 #include "../Sources/RestApi/RestApiHierarchy.h"
 #include "../Sources/WebServiceParameters.h"
-#include "../Sources/MetricsRegistry.h"
 
 #include <ctype.h>
 #include <boost/lexical_cast.hpp>
@@ -117,7 +116,7 @@ TEST(HttpClient, Basic)
 
 TEST(HttpClient, Ssl)
 {
-  SystemToolbox::WriteFile(GITHUB_CERTIFICATES, "UnitTestsResults/github.cert");
+  SystemToolbox::WriteFile(GITHUB_CERTIFICATES, SystemToolbox::PathFromUtf8("UnitTestsResults/github.cert"));
 
   /*{
     std::string s;
@@ -402,7 +401,7 @@ namespace
     void Reset()
     {
       HttpContentNegociation::Dictionary parameters;
-      Handle("nope", "nope", parameters);
+      AcceptHandler::Handle("nope", "nope", parameters);
     }
 
     const std::string& GetType() const
@@ -1316,7 +1315,7 @@ namespace
       {
         if (b[i] != ('0' + i % 7))
         {
-          throw;
+          throw OrthancException(ErrorCode_InternalError);
         }
       }
       
@@ -1388,6 +1387,7 @@ TEST(HttpClient, DISABLED_Issue156_Crash)
 #endif
 
 
+#if ORTHANC_SANDBOXED != 1
 TEST(HttpServer, GetRelativePathToRoot)
 {
   ASSERT_THROW(HttpServer::GetRelativePathToRoot(""), OrthancException);
@@ -1397,3 +1397,4 @@ TEST(HttpServer, GetRelativePathToRoot)
   ASSERT_EQ("./../../", HttpServer::GetRelativePathToRoot("/a/b/system"));
   ASSERT_EQ("../../../", HttpServer::GetRelativePathToRoot("/a/b/system/"));
 }
+#endif
