@@ -115,10 +115,16 @@ private:
 
     void RegisterWorklistCallback(const void* parameters);
 
+    void RegisterWorklistCallback2(const void* parameters);
+
     void RegisterFindCallback(const void* parameters);
 
+    void RegisterFindCallback2(const void* parameters);
+
     void RegisterMoveCallback(const void* parameters);
 
+    void RegisterMoveCallback2(const void* parameters);
+
     void RegisterDecodeImageCallback(const void* parameters);
 
     void RegisterTranscoderCallback(const void* parameters);
@@ -139,6 +145,8 @@ private:
 
     void RegisterStorageCommitmentScpCallback(const void* parameters);
 
+    void RegisterStorageCommitmentScpCallback2(const void* parameters);
+
     void RegisterHttpAuthentication(const void* parameters);
 
     void RegisterAuditLogHandler(const void* parameters);
@@ -173,7 +181,10 @@ private:
     
     void AccessDicomInstance2(_OrthancPluginService service,
                               const void* parameters);
-    
+
+    void AccessDicomConnection(_OrthancPluginService service,
+                               const void* parameters);
+
     void SendHttpStatusCode(const void* parameters);
 
     void SendHttpStatus(const void* parameters);
@@ -249,6 +260,10 @@ private:
 
     void ApplyGetQueueSize(const _OrthancPluginGetQueueSize& parameters);
 
+    void ApplyReserveQueueValue(const _OrthancPluginReserveQueueValue& parameters);
+
+    void ApplyAknowledgeQueueValue(const _OrthancPluginAcknowledgeQueueValue& parameters);
+
     void ApplySetStableStatus(const _OrthancPluginSetStableStatus& parameters);
 
     void ApplyEmitAuditLog(const _OrthancPluginEmitAuditLog& parameters);
@@ -281,7 +296,7 @@ private:
   public:
     explicit OrthancPlugins(const std::string& databaseServerIdentifier);
 
-    virtual ~OrthancPlugins();
+    virtual ~OrthancPlugins() ORTHANC_OVERRIDE;
 
     void SetServerContext(ServerContext& context);
 
@@ -338,7 +353,7 @@ private:
     const char* GetProperty(const char* plugin,
                             _OrthancPluginProperty property) const;
 
-    void SetCommandLineArguments(int argc, char* argv[]);
+    void SetCommandLineArguments(const std::vector<std::string>& arguments);
 
     PluginsManager& GetManager();
 
@@ -414,8 +429,7 @@ private:
       const std::string& transactionUid,
       const std::vector<std::string>& sopClassUids,
       const std::vector<std::string>& sopInstanceUids,
-      const std::string& remoteAet,
-      const std::string& calledAet) ORTHANC_OVERRIDE;
+      const DicomConnectionInfo& connection) ORTHANC_OVERRIDE;
 
     // New in Orthanc 1.8.1 (cf. "OrthancPluginGenerateRestApiAuthorizationToken()")
     bool IsValidAuthorizationToken(const std::string& token) const;
