@@ -41,6 +41,7 @@
 
 static int globalPropertyId_ = 0;
 static bool force_ = false;
+static bool forceReconstructFiles_ = false;
 static unsigned int throttleDelay_ = 0;
 static std::unique_ptr<boost::thread> workerThread_;
 static bool workerThreadShouldStop_ = false;
@@ -106,7 +107,7 @@ struct RunningPeriod
   bool isInPeriod() const
   {
     time_t now = time(NULL);
-    tm* nowLocalTime = localtime(&now);
+    const tm* nowLocalTime = localtime(&now);
 
     if (nowLocalTime->tm_wday != weekday_)
     {
@@ -568,10 +569,10 @@ static bool ProcessChanges(bool needsReconstruct, bool needsReingest, bool needs
           {
             Json::Value result;
 
-            if (needsReconstruct || needsReingest ||force_)
+            if (needsReconstruct || needsReingest || force_)
             {
               Json::Value request;
-              if (needsReingest)
+              if (needsReingest || forceReconstructFiles_)
               {
                 request["ReconstructFiles"] = true;
               }
@@ -651,6 +652,13 @@ static void WorkerThread()
     needsFullProcessing = needsReconstruct || needsReingest || needsDicomWebCaching;
     needsProcessing = needsFullProcessing;
 
+    if (needsFullProcessing && !limitToChange_.empty())
+    {
+      ORTHANC_PLUGINS_LOG_WARNING("Housekeeper: full processing needed -> ignoring the \"LimitMainDicomTagsReconstructLevel\" configuration");
+      limitToChange_.clear();
+      limitToUrl_.clear();
+    }
+
       // if a processing was in progress, check if the config has changed since
     if (pluginStatus_.currentlyProcessingConfiguration.IsDefined())
     {
@@ -679,7 +687,7 @@ static void WorkerThread()
     }
     else
     {
-      ORTHANC_PLUGINS_LOG_WARNING("Housekeeper: the DB configuration has changed since last run, will reprocess the whole DB !");
+      ORTHANC_PLUGINS_LOG_WARNING("Housekeeper: the Orthanc configuration has changed since last run, will reprocess the whole DB !");
     }
     
     Json::Value changes;
@@ -695,7 +703,7 @@ static void WorkerThread()
   }
   else
   {
-    ORTHANC_PLUGINS_LOG_WARNING("Housekeeper: the DB configuration has not changed since last run, will continue processing changes");
+    ORTHANC_PLUGINS_LOG_WARNING("Housekeeper: the Orthanc configuration has not changed since last run, will continue processing changes");
   }
 
   bool completed = false;
@@ -849,6 +857,13 @@ extern "C"
             // any changes in configuration
             "Force": false,
 
+            // New in 1.12.9
+            // If "Force" is set to true, forces the "ReconstructFiles"
+            // option when reconstructing resources even if the plugin 
+            // did not detect any changes in the configuration that 
+            // should trigger a Reconstruct.
+            "ForceReconstructFiles": false,
+
             // Delay (in seconds) between reconstruction of 2 studies
             // This avoids overloading Orthanc with the housekeeping
             // process and leaves room for other operations.
@@ -891,6 +906,7 @@ extern "C"
 
       globalPropertyId_ = housekeeper.GetIntegerValue("GlobalPropertyId", 1025);
       force_ = housekeeper.GetBooleanValue("Force", false);
+      forceReconstructFiles_ = housekeeper.GetBooleanValue("ForceReconstructFiles", false);
       throttleDelay_ = housekeeper.GetUnsignedIntegerValue("ThrottleDelay", 5);      
 
       if (housekeeper.GetJson().isMember("Triggers"))
