@@ -44,5 +44,7 @@ public:
   virtual uint16_t Handle(DcmDataset& dicom,
                           const std::string& remoteIp,
                           const std::string& remoteAet,
-                          const std::string& calledAet) ORTHANC_OVERRIDE;
+                          const std::string& calledAet,
+                          uint16_t originatorMessageId,
+                          const std::string& originatorAet) ORTHANC_OVERRIDE;
 };
