@@ -3,7 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +25,8 @@
 
 #include <json/value.h>
 
+#define ORTHANC_PLUGIN_NAME  "storage-commitment-scp"
+
 
 class StorageCommitmentSample : public OrthancPlugins::IStorageCommitmentScpHandler
 {
@@ -86,7 +89,7 @@ extern "C"
       return -1;
     }
 
-    OrthancPluginSetDescription(c, "Sample storage commitment SCP plugin.");
+    OrthancPlugins::SetDescription(ORTHANC_PLUGIN_NAME, "Sample storage commitment SCP plugin.");
 
     OrthancPluginRegisterStorageCommitmentScpCallback(
       c, StorageCommitmentScp,
@@ -104,7 +107,7 @@ extern "C"
 
   ORTHANC_PLUGINS_API const char* OrthancPluginGetName()
   {
-    return "storage-commitment-scp";
+    return ORTHANC_PLUGIN_NAME;
   }
 
 
