@@ -27,12 +27,43 @@
 
 #include <stdio.h>
 
-int main(int argc, const char* argv[])
+#if defined(_WIN32) || defined(__CYGWIN__)
+#include <windows.h>
+#endif
+
+
+#if defined(_WIN32) && !defined(__MINGW32__)
+// arguments are passed as UTF-16 on Windows
+int wmain(int argc, wchar_t *argv[])
 {
-  if (argc != 2 && argc != 3)
+  // Set Windows console output to UTF-8 (otherwise, strings are considered to be in UTF-16.  For example, Cyrillic UTF-8 strings appear as garbage without that config)
+  SetConsoleOutputCP(CP_UTF8);
+
+  // Transform the UTF-16 arguments into UTF-8 arguments
+  std::vector<std::string> arguments; // UTF-8 arguments
+
+  for (int i = 0; i < argc; i++)
+  {
+    std::wstring argument(argv[i]);
+    arguments.push_back(Orthanc::SystemToolbox::WStringToUtf8(argument));
+  }
+
+#else
+int main(int argc, char *argv[])
+{
+  std::vector<std::string> arguments; // UTF-8 arguments
+
+  // the arguments are assumed to be directly in UTF-8
+  for (int i = 0; i < argc; i++)
+  {
+    arguments.push_back(argv[i]);
+  }
+#endif
+
+  if (arguments.size() != 2 && arguments.size() != 3)
   {
     fprintf(stderr, "Maintenance tool to recover a DICOM file that was compressed by Orthanc.\n\n");
-    fprintf(stderr, "Usage: %s <input> [output]\n", argv[0]);
+    fprintf(stderr, "Usage: %s <input> [output]\n", arguments[0].c_str());
     fprintf(stderr, "If \"output\" is not given, the data will be output to stdout\n");
     return -1;
   }
@@ -43,7 +74,7 @@ int main(int argc, const char* argv[])
     fflush(stderr);
 
     std::string content;
-    Orthanc::SystemToolbox::ReadFile(content, argv[1]);
+    Orthanc::SystemToolbox::ReadFile(content, Orthanc::SystemToolbox::PathFromUtf8(arguments[1]));
 
     fprintf(stderr, "Decompressing the content of the file...\n");
     fflush(stderr);
@@ -59,7 +90,7 @@ int main(int argc, const char* argv[])
 
     if (argc == 3)
     {
-      Orthanc::SystemToolbox::WriteFile(uncompressed, argv[2]);
+      Orthanc::SystemToolbox::WriteFile(uncompressed, Orthanc::SystemToolbox::PathFromUtf8(arguments[2]));
     }
     else
     {
