@@ -59,6 +59,7 @@ namespace Orthanc
       bool hasAttachmentCustomDataSupport_;
       bool hasKeyValueStoresSupport_;
       bool hasQueuesSupport_;
+      bool hasReserveQueueValueSupport_;
 
     public:
       Capabilities() :
@@ -72,7 +73,8 @@ namespace Orthanc
         hasExtendedChanges_(false),
         hasAttachmentCustomDataSupport_(false),
         hasKeyValueStoresSupport_(false),
-        hasQueuesSupport_(false)
+        hasQueuesSupport_(false),
+        hasReserveQueueValueSupport_(false)
       {
       }
 
@@ -186,6 +188,16 @@ namespace Orthanc
         return hasQueuesSupport_;
       }
 
+      void SetReserveQueueValueSupport(bool value)
+      {
+        hasReserveQueueValueSupport_ = value;
+      }
+
+      bool HasReserveQueueValueSupport() const
+      {
+        return hasReserveQueueValueSupport_;
+      }
+
     };
 
 
@@ -471,6 +483,17 @@ namespace Orthanc
       // New in Orthanc 1.12.8, for statistics only
       virtual uint64_t GetQueueSize(const std::string& queueId) = 0;
 
+      // New in Orthanc 1.12.10
+      virtual bool ReserveQueueValue(std::string& value /* out */,
+                                     uint64_t& valueId /* out */, 
+                                     const std::string& queueId,
+                                     QueueOrigin origin,
+                                     uint32_t releaseTimeout) = 0;
+      
+      // New in Orthanc 1.12.10
+      virtual void AcknowledgeQueueValue(const std::string& queueId,
+                                         uint64_t valueId) = 0;
+
     };
 
 
