@@ -827,7 +827,16 @@ namespace Orthanc
     if (state_ == State_Running)
     {
       LOG(ERROR) << "INTERNAL ERROR: LuaScripting::Stop() should be invoked manually to avoid mess in the destruction order!";
-      Stop();
+
+      try
+      {
+        Stop();
+      }
+      catch (OrthancException& e)
+      {
+        // Don't throw exceptions in destructors
+        LOG(ERROR) << "Exception in destructor: " << e.What();
+      }
     }
   }
 
@@ -1034,7 +1043,7 @@ namespace Orthanc
     return true;
   }
 
-  bool LuaScripting::FilterIncomingCStoreInstance(uint16_t& dimseStatus,
+  bool LuaScripting::FilterIncomingCStoreInstance(uint16_t& /*dimseStatus*/,
                                                   const DicomInstanceToStore& instance,
                                                   const Json::Value& simplified)
   {
@@ -1096,8 +1105,8 @@ namespace Orthanc
     for (std::list<std::string>::const_iterator
            it = luaScripts.begin(); it != luaScripts.end(); ++it)
     {
-      std::string path = configLock.GetConfiguration().InterpretStringParameterAsPath(*it);
-      LOG(INFO) << "Installing the Lua scripts from: " << path;
+      boost::filesystem::path path = configLock.GetConfiguration().InterpretStringParameterAsPath(*it);
+      LOG(INFO) << "Installing the Lua scripts from: " << SystemToolbox::PathToUtf8(path);
       std::string script;
       SystemToolbox::ReadFile(script, path);
 
