@@ -40,17 +40,13 @@ namespace Orthanc
     bool HasReachedLimit(const DicomFindAnswers& answers,
                          ResourceType level) const;
 
-    bool FilterQueryTag(std::string& value /* can be modified */,
-                        ResourceType level,
+    bool FilterQueryTag(ResourceType level,
                         const DicomTag& tag,
                         ModalityManufacturer manufacturer);
 
     bool ApplyLuaFilter(DicomMap& target,
                         const DicomMap& source,
-                        const std::string& remoteIp,
-                        const std::string& remoteAet,
-                        const std::string& calledAet,
-                        ModalityManufacturer manufacturer);
+                        const DicomConnectionInfo& connection);
 
   public:
     explicit OrthancFindRequestHandler(ServerContext& context);
@@ -58,10 +54,7 @@ namespace Orthanc
     virtual void Handle(DicomFindAnswers& answers,
                         const DicomMap& input,
                         const std::list<DicomTag>& sequencesToReturn,
-                        const std::string& remoteIp,
-                        const std::string& remoteAet,
-                        const std::string& calledAet,
-                        ModalityManufacturer manufacturer) ORTHANC_OVERRIDE;
+                        const DicomConnectionInfo& connection) ORTHANC_OVERRIDE;
 
     unsigned int GetMaxResults() const
     {
@@ -84,9 +77,6 @@ namespace Orthanc
     }
 
     static void FormatOrigin(Json::Value& origin,
-                             const std::string& remoteIp,
-                             const std::string& remoteAet,
-                             const std::string& calledAet,
-                             ModalityManufacturer manufacturer);
+                             const DicomConnectionInfo& connection);
   };
 }
