@@ -133,13 +133,14 @@ namespace Orthanc
     LST_HEAD **l = &assoc->params->DULparams.acceptedPresentationContext;
     if (*l != NULL)
     {
-      DUL_PRESENTATIONCONTEXT* pc = (DUL_PRESENTATIONCONTEXT*) LST_Head(l);
-      LST_Position(l, (LST_NODE*)pc);
+      DUL_PRESENTATIONCONTEXT* pc = reinterpret_cast<DUL_PRESENTATIONCONTEXT*>(LST_Head(l));
+      LST_Position(l, reinterpret_cast<LST_NODE*>(pc));
       while (pc)
       {
-        DicomTransferSyntax transferSyntax;
         if (pc->result == ASC_P_ACCEPTANCE)
         {
+          DicomTransferSyntax transferSyntax;
+          
           if (LookupTransferSyntax(transferSyntax, pc->acceptedTransferSyntax))
           {
             /*CLOG(TRACE, DICOM) << "C-GET SCP accepted: SOP class " << pc->abstractSyntax
@@ -156,7 +157,7 @@ namespace Orthanc
           }
         }
             
-        pc = (DUL_PRESENTATIONCONTEXT*) LST_Next(l);
+        pc = reinterpret_cast<DUL_PRESENTATIONCONTEXT*>(LST_Next(l));
       }
     }
 
@@ -324,7 +325,7 @@ namespace Orthanc
       std::set<DicomTransferSyntax> ts;
       ts.insert(selectedSyntax);
       
-      if (context_.Transcode(transcoded, source, ts, true))
+      if (context_.Transcode(transcoded, source, ts, TranscodingSopInstanceUidMode_AllowNew))
       {
         // Transcoding has succeeded
         DcmDataset *stDetailTmp = NULL;
