@@ -36,10 +36,27 @@
 #  include <malloc.h>
 #endif
 
+
+// This must be *before* the inclusion of "Logging.h"
+#if defined(__ORTHANC_FILE__)
+// Prevents the system-wide Google Protobuf library from leaking the
+// full path of this source file
+#  undef __FILE__
+#  define __FILE__ __ORTHANC_FILE__
+#endif
+
+
+#if ORTHANC_ENABLE_PLUGINS == 1
+#  include <google/protobuf/stubs/common.h>
+#  include <google/protobuf/any.h>
+#endif
+
+
 #include "OrthancInitialization.h"
 
 #include "../../OrthancFramework/Sources/DicomParsing/FromDcmtkBridge.h"
 #include "../../OrthancFramework/Sources/FileStorage/FilesystemStorage.h"
+#include "../../OrthancFramework/Sources/FileStorage/PluginStorageAreaAdapter.h"
 #include "../../OrthancFramework/Sources/HttpClient.h"
 #include "../../OrthancFramework/Sources/Logging.h"
 #include "../../OrthancFramework/Sources/OrthancException.h"
@@ -52,15 +69,6 @@
 
 #include <dcmtk/dcmnet/diutil.h>  // For DCM_dcmnetLogger
 
-#if ORTHANC_ENABLE_PLUGINS == 1
-#  if defined(__ORTHANC_FILE__)
-//   Prevents the system-wide Google Protobuf library from leaking the
-//   full path of this source file
-#    undef __FILE__
-#    define __FILE__ __ORTHANC_FILE__
-#  endif
-#  include <google/protobuf/any.h>
-#endif
 
 
 static const char* const STORAGE_DIRECTORY = "StorageDirectory";
@@ -326,7 +334,7 @@ namespace Orthanc
 
 
 
-  void OrthancInitialize(const char* configurationFile)
+  void OrthancInitialize(const boost::filesystem::path& configurationFile)
   {
     static const char* const LOCALE = "Locale";
     static const char* const PKCS11 = "Pkcs11";
@@ -434,7 +442,7 @@ namespace Orthanc
     boost::filesystem::path indexDirectory = lock.GetConfiguration().InterpretStringParameterAsPath(
       lock.GetConfiguration().GetStringParameter("IndexDirectory", storageDirectoryStr));
 
-    LOG(WARNING) << "SQLite index directory: " << indexDirectory;
+    LOG(WARNING) << "SQLite index directory: " << SystemToolbox::PathToUtf8(indexDirectory);
 
     try
     {
@@ -444,7 +452,7 @@ namespace Orthanc
     {
     }
 
-    return new SQLiteDatabaseWrapper(indexDirectory.string() + "/index");
+    return new SQLiteDatabaseWrapper(Orthanc::SystemToolbox::PathToUtf8(indexDirectory) + "/index");
   }
 
 
@@ -458,7 +466,7 @@ namespace Orthanc
       FilesystemStorage storage_;
 
     public:
-      FilesystemStorageWithoutDicom(const std::string& path,
+      FilesystemStorageWithoutDicom(const boost::filesystem::path& path,
                                     bool fsyncOnWrite) :
         storage_(path, fsyncOnWrite)
       {
@@ -475,19 +483,6 @@ namespace Orthanc
         }
       }
 
-      virtual IMemoryBuffer* Read(const std::string& uuid,
-                                  FileContentType type) ORTHANC_OVERRIDE
-      {
-        if (type != FileContentType_Dicom)
-        {
-          return storage_.Read(uuid, type);
-        }
-        else
-        {
-          throw OrthancException(ErrorCode_UnknownResource);
-        }
-      }
-
       virtual IMemoryBuffer* ReadRange(const std::string& uuid,
                                        FileContentType type,
                                        uint64_t start /* inclusive */,
@@ -503,9 +498,9 @@ namespace Orthanc
         }
       }
 
-      virtual bool HasReadRange() const ORTHANC_OVERRIDE
+      virtual bool HasEfficientReadRange() const ORTHANC_OVERRIDE
       {
-        return storage_.HasReadRange();
+        return storage_.HasEfficientReadRange();
       }
 
       virtual void Remove(const std::string& uuid,
@@ -520,7 +515,7 @@ namespace Orthanc
   }
 
 
-  static IStorageArea* CreateFilesystemStorage()
+  static IPluginStorageArea* CreateFilesystemStorage()
   {
     static const char* const SYNC_STORAGE_AREA = "SyncStorageArea";
     static const char* const STORE_DICOM = "StoreDicom";
@@ -533,19 +528,19 @@ namespace Orthanc
     boost::filesystem::path storageDirectory = 
       lock.GetConfiguration().InterpretStringParameterAsPath(storageDirectoryStr);
 
-    LOG(WARNING) << "Storage directory: " << storageDirectory;
+    LOG(WARNING) << "Storage directory: " << SystemToolbox::PathToUtf8(storageDirectory);
 
     // New in Orthanc 1.7.4
     bool fsyncOnWrite = lock.GetConfiguration().GetBooleanParameter(SYNC_STORAGE_AREA, true);
 
     if (lock.GetConfiguration().GetBooleanParameter(STORE_DICOM, true))
     {
-      return new FilesystemStorage(storageDirectory.string(), fsyncOnWrite);
+      return new PluginStorageAreaAdapter(new FilesystemStorage(storageDirectory, fsyncOnWrite));
     }
     else
     {
       LOG(WARNING) << "The DICOM files will not be stored, Orthanc running in index-only mode";
-      return new FilesystemStorageWithoutDicom(storageDirectory.string(), fsyncOnWrite);
+      return new PluginStorageAreaAdapter(new FilesystemStorageWithoutDicom(storageDirectory, fsyncOnWrite));
     }
   }
 
@@ -556,7 +551,7 @@ namespace Orthanc
   }
 
 
-  IStorageArea* CreateStorageArea()
+  IPluginStorageArea* CreateStorageArea()
   {
     return CreateFilesystemStorage();
   }
