@@ -29,7 +29,7 @@
 
 namespace Orthanc
 {
-  void OrthancInitialize(const char* configurationFile = NULL);
+  void OrthancInitialize(const boost::filesystem::path& configurationFile);
 
   void OrthancFinalize();
 
