@@ -99,6 +99,7 @@ namespace Orthanc
     static const char* const HAS_QUEUES = "HasQueues";
     static const char* const HAS_EXTENDED_FIND = "HasExtendedFind";
     static const char* const READ_ONLY = "ReadOnly";
+    static const char* const HAS_RESERVE_QUEUE_VALUE = "HasReserveQueueValue";
 
     if (call.IsDocumentation())
     {
@@ -147,7 +148,9 @@ namespace Orthanc
         .SetAnswerField(HAS_LABELS, RestApiCallDocumentation::Type_Boolean,
                         "Whether the database back-end supports labels (new in Orthanc 1.12.0)")
         .SetAnswerField(CAPABILITIES, RestApiCallDocumentation::Type_JsonObject,
-                        "Whether the back-end supports optional features like 'HasExtendedChanges', 'HasExtendedFind' (new in Orthanc 1.12.5) ")
+                        "Whether the database back-end supports optional features like 'HasExtendedChanges', 'HasExtendedFind' "
+                        "(new in Orthanc 1.12.5), 'HasKeyValueStores', 'HasQueues' (new in Orthanc 1.12.8), "
+                        "and 'HasReserveQueueValue' (new in Orthanc 1.12.10)")
         .SetAnswerField(READ_ONLY, RestApiCallDocumentation::Type_Boolean,
                         "Whether Orthanc is running in read only mode (new in Orthanc 1.12.5)")
         .SetHttpGetSample("https://orthanc.uclouvain.be/demo/system", true);
@@ -190,14 +193,12 @@ namespace Orthanc
 
     if (plugins.HasStorageArea())
     {
-      std::string p = plugins.GetStorageAreaLibrary().GetPath();
-      result[STORAGE_AREA_PLUGIN] = boost::filesystem::canonical(p).string();
+      result[STORAGE_AREA_PLUGIN] = SystemToolbox::PathToUtf8(plugins.GetStorageAreaLibrary().GetPath());
     }
 
     if (plugins.HasDatabaseBackend())
     {
-      std::string p = plugins.GetDatabaseBackendLibrary().GetPath();
-      result[DATABASE_BACKEND_PLUGIN] = boost::filesystem::canonical(p).string();     
+      result[DATABASE_BACKEND_PLUGIN] = SystemToolbox::PathToUtf8(plugins.GetDatabaseBackendLibrary().GetPath());
     }
 #else
     result[PLUGINS_ENABLED] = false;
@@ -215,6 +216,7 @@ namespace Orthanc
     result[CAPABILITIES][HAS_EXTENDED_FIND] = OrthancRestApi::GetIndex(call).HasFindSupport();
     result[CAPABILITIES][HAS_KEY_VALUE_STORES] = OrthancRestApi::GetIndex(call).HasKeyValueStoresSupport();
     result[CAPABILITIES][HAS_QUEUES] = OrthancRestApi::GetIndex(call).HasQueuesSupport();
+    result[CAPABILITIES][HAS_RESERVE_QUEUE_VALUE] = OrthancRestApi::GetIndex(call).HasReserveQueueValueSupport();
     
     call.GetOutput().AnswerJson(result);
   }
