@@ -99,9 +99,9 @@ namespace Orthanc
                   bool allowDicomDelete,
                   bool allowUpload);
 
-    virtual ~OrthancWebDav()
+    virtual ~OrthancWebDav() ORTHANC_OVERRIDE
     {
-      Stop();
+      OrthancWebDav::Stop();
     }
 
     virtual bool IsExistingFolder(const UriComponents& path) ORTHANC_OVERRIDE;
