@@ -50,6 +50,7 @@
 
 #include <dcmtk/dcmdata/dcfilefo.h>
 #include <dcmtk/dcmnet/dimse.h>
+#include <dcmtk/dcmdata/dcdeftag.h>
 #include <dcmtk/dcmdata/dcuid.h>        /* for variable dcmAllStorageSOPClassUIDs */
 
 #include <boost/regex.hpp>
@@ -855,11 +856,11 @@ namespace Orthanc
 
           case StoreStatus_Failure:
             LOG(ERROR) << "Unknown store failure while storing instance " << resultPublicId;
-            throw OrthancException(ErrorCode_InternalError, HttpStatus_500_InternalServerError);
+            throw OrthancException(ErrorCode_InternalError).SetHttpStatus(HttpStatus_500_InternalServerError);
 
           case StoreStatus_StorageFull:
             LOG(ERROR) << "Storage full while storing instance " << resultPublicId;
-            throw OrthancException(ErrorCode_FullStorage, HttpStatus_507_InsufficientStorage);
+            throw OrthancException(ErrorCode_FullStorage).SetHttpStatus(HttpStatus_507_InsufficientStorage);
 
           default:
             // This should never happen
@@ -1017,7 +1018,7 @@ namespace Orthanc
         
         IDicomTranscoder::DicomImage transcoded;
         
-        if (Transcode(transcoded, source, syntaxes, true /* allow new SOP instance UID */))
+        if (Transcode(transcoded, source, syntaxes, TranscodingSopInstanceUidMode_AllowNew /* allow new SOP instance UID */))
         {
           std::unique_ptr<ParsedDicomFile> tmp(transcoded.ReleaseAsParsedDicomFile());
 
@@ -1828,14 +1829,13 @@ namespace Orthanc
                                          const std::string& transactionUid,
                                          const std::vector<std::string>& sopClassUids,
                                          const std::vector<std::string>& sopInstanceUids,
-                                         const std::string& remoteAet,
-                                         const std::string& calledAet)
+                                         const DicomConnectionInfo& connection)
   {
 #if ORTHANC_ENABLE_PLUGINS == 1
     if (HasPlugins())
     {
       return GetPlugins().CreateStorageCommitment(
-        jobId, transactionUid, sopClassUids, sopInstanceUids, remoteAet, calledAet);
+        jobId, transactionUid, sopClassUids, sopInstanceUids, connection);
     }
 #endif
 
@@ -1885,7 +1885,7 @@ namespace Orthanc
           return decoded.release();
         }
       }
-      catch (OrthancException& e)
+      catch (const OrthancException&)
       { // ignore, we'll try other alternatives
       }
     }
@@ -1898,7 +1898,7 @@ namespace Orthanc
       {
         decoded.reset(GetPlugins().Decode(buffer, size, frameIndex));
       }
-      catch (OrthancException& e)
+      catch (const OrthancException&)
       {
       }
       
@@ -1942,7 +1942,7 @@ namespace Orthanc
       source.SetExternalBuffer(buffer, size);
       allowedSyntaxes.insert(DicomTransferSyntax_LittleEndianExplicit);
 
-      if (Transcode(explicitTemporaryImage, source, allowedSyntaxes, true))
+      if (Transcode(explicitTemporaryImage, source, allowedSyntaxes, TranscodingSopInstanceUidMode_AllowNew))
       {
         std::unique_ptr<ParsedDicomFile> file(explicitTemporaryImage.ReleaseAsParsedDicomFile());
         return file->DecodeFrame(frameIndex);
@@ -1974,13 +1974,13 @@ namespace Orthanc
   }
   
 
-  void ServerContext::StoreWithTranscoding(std::string& sopClassUid,
-                                           std::string& sopInstanceUid,
-                                           DicomStoreUserConnection& connection,
-                                           const std::string& dicom,
-                                           bool hasMoveOriginator,
-                                           const std::string& moveOriginatorAet,
-                                           uint16_t moveOriginatorId)
+  void ServerContext::PerformCStoreWithTranscoding(std::string& sopClassUid,
+                                                   std::string& sopInstanceUid,
+                                                   DicomStoreUserConnection& connection,
+                                                   const std::string& dicom,
+                                                   bool hasMoveOriginator,
+                                                   const std::string& moveOriginatorAet,
+                                                   uint16_t moveOriginatorId)
   {
     const void* data = dicom.empty() ? NULL : dicom.c_str();
     const RemoteModalityParameters& modality = connection.GetParameters().GetRemoteModality();
@@ -2016,7 +2016,7 @@ namespace Orthanc
       std::set<DicomTransferSyntax> syntaxes;
       syntaxes.insert(targetSyntax);
 
-      if (Transcode(targetDicom, sourceDicom, syntaxes, true))
+      if (Transcode(targetDicom, sourceDicom, syntaxes, TranscodingSopInstanceUidMode_AllowNew))
       {
         cacheAccessor.AddTranscodedInstance(attachmentId, targetSyntax, reinterpret_cast<const char*>(targetDicom.GetBufferData()), targetDicom.GetBufferSize());
         target = std::string(reinterpret_cast<const char*>(targetDicom.GetBufferData()), targetDicom.GetBufferSize());
@@ -2032,7 +2032,7 @@ namespace Orthanc
   bool ServerContext::Transcode(DicomImage& target,
                                 DicomImage& source /* in, "GetParsed()" possibly modified */,
                                 const std::set<DicomTransferSyntax>& allowedSyntaxes,
-                                bool allowNewSopInstanceUid)
+                                TranscodingSopInstanceUidMode mode)
   {
     unsigned int lossyQuality;
 
@@ -2041,19 +2041,19 @@ namespace Orthanc
       lossyQuality = lock.GetConfiguration().GetDicomLossyTranscodingQuality();
     }
 
-    return Transcode(target, source, allowedSyntaxes, allowNewSopInstanceUid, lossyQuality);
+    return Transcode(target, source, allowedSyntaxes, mode, lossyQuality);
   }
 
 
   bool ServerContext::Transcode(DicomImage& target,
                                 DicomImage& source /* in, "GetParsed()" possibly modified */,
                                 const std::set<DicomTransferSyntax>& allowedSyntaxes,
-                                bool allowNewSopInstanceUid,
+                                TranscodingSopInstanceUidMode mode,
                                 unsigned int lossyQuality)
   {
     if (builtinDecoderTranscoderOrder_ == BuiltinDecoderTranscoderOrder_Before)
     {
-      if (dcmtkTranscoder_->Transcode(target, source, allowedSyntaxes, allowNewSopInstanceUid, lossyQuality))
+      if (dcmtkTranscoder_->Transcode(target, source, allowedSyntaxes, mode, lossyQuality))
       {
         return true;
       }
@@ -2063,7 +2063,7 @@ namespace Orthanc
     if (HasPlugins() &&
         GetPlugins().HasCustomTranscoder())
     {
-      if (GetPlugins().Transcode(target, source, allowedSyntaxes, allowNewSopInstanceUid))  // TODO: pass lossyQuality to plugins -> needs a new plugin interface
+      if (GetPlugins().Transcode(target, source, allowedSyntaxes, mode))  // TODO: pass lossyQuality to plugins -> needs a new plugin interface
       {
         return true;
       }
@@ -2077,7 +2077,7 @@ namespace Orthanc
 
     if (builtinDecoderTranscoderOrder_ == BuiltinDecoderTranscoderOrder_After)
     {
-      return dcmtkTranscoder_->Transcode(target, source, allowedSyntaxes, allowNewSopInstanceUid, lossyQuality);
+      return dcmtkTranscoder_->Transcode(target, source, allowedSyntaxes, mode, lossyQuality);
     }
     else
     {
@@ -2085,6 +2085,7 @@ namespace Orthanc
     }
   }
 
+
   const std::string& ServerContext::GetDeidentifiedContent(const DicomElement &element) const
   {
     static const std::string redactedContent = "*** POTENTIAL PHI ***";
