@@ -319,7 +319,7 @@ namespace Orthanc
                   bool readOnly,
                   unsigned int maxConcurrentDcmtkTranscoder);
 
-    ~ServerContext();
+    ~ServerContext() ORTHANC_OVERRIDE;
 
     void SetupJobsEngine(bool unitTesting,
                          bool loadJobsFromDatabase);
@@ -554,8 +554,7 @@ namespace Orthanc
                             const std::string& transactionUid,
                             const std::vector<std::string>& sopClassUids,
                             const std::vector<std::string>& sopInstanceUids,
-                            const std::string& remoteAet,
-                            const std::string& calledAet) ORTHANC_OVERRIDE;
+                            const DicomConnectionInfo& connection) ORTHANC_OVERRIDE;
 
     StorageCommitmentReports& GetStorageCommitmentReports()
     {
@@ -577,25 +576,25 @@ namespace Orthanc
                                     size_t size,
                                     unsigned int frameIndex);
 
-    void StoreWithTranscoding(std::string& sopClassUid,
-                              std::string& sopInstanceUid,
-                              DicomStoreUserConnection& connection,
-                              const std::string& dicom,
-                              bool hasMoveOriginator,
-                              const std::string& moveOriginatorAet,
-                              uint16_t moveOriginatorId);
+    void PerformCStoreWithTranscoding(std::string& sopClassUid,
+                                      std::string& sopInstanceUid,
+                                      DicomStoreUserConnection& connection,
+                                      const std::string& dicom,
+                                      bool hasMoveOriginator,
+                                      const std::string& moveOriginatorAet,
+                                      uint16_t moveOriginatorId);
 
     // This method can be used even if the global option
     // "TranscodeDicomProtocol" is set to "false"
     virtual bool Transcode(DicomImage& target,
                            DicomImage& source /* in, "GetParsed()" possibly modified */,
                            const std::set<DicomTransferSyntax>& allowedSyntaxes,
-                           bool allowNewSopInstanceUid) ORTHANC_OVERRIDE;
-    
+                           TranscodingSopInstanceUidMode mode) ORTHANC_OVERRIDE;
+
     virtual bool Transcode(DicomImage& target,
                            DicomImage& source /* in, "GetParsed()" possibly modified */,
                            const std::set<DicomTransferSyntax>& allowedSyntaxes,
-                           bool allowNewSopInstanceUid,
+                           TranscodingSopInstanceUidMode mode,
                            unsigned int lossyQuality) ORTHANC_OVERRIDE;
 
     virtual bool TranscodeWithCache(std::string& target,
