@@ -64,6 +64,8 @@ namespace Orthanc
     dictMetadataType_.Add(MetadataType_MainDicomTagsSignature, "MainDicomTagsSignature");
     dictMetadataType_.Add(MetadataType_MainDicomSequences, "MainDicomSequences");
     dictMetadataType_.Add(MetadataType_Instance_PixelDataVR, "PixelDataVR");
+    dictMetadataType_.Add(MetadataType_Patient_IsProtected, "IsProtected");
+    dictMetadataType_.Add(MetadataType_Patient_PatientRecyclingOrder, "PatientRecyclingOrder");
 
     dictContentType_.Add(FileContentType_Dicom, "dicom");
     dictContentType_.Add(FileContentType_DicomAsJson, "dicom-as-json");
@@ -655,6 +657,10 @@ namespace Orthanc
     {
       return ResponseContentFlags_IsStable;
     }
+    else if (value == "IsProtected")
+    {
+      return ResponseContentFlags_IsProtected;
+    }
     else
     {
       throw OrthancException(ErrorCode_ParameterOutOfRange,
