@@ -185,7 +185,7 @@ namespace Orthanc
       for (std::set<std::string>::const_iterator it = instancesToReconstruct_.begin(); it != instancesToReconstruct_.end(); ++it)
       {
         ServerContext::DicomCacheLocker locker(GetContext(), *it);
-        ParsedDicomFile& modifiedDicom = locker.GetDicom();
+        const ParsedDicomFile& modifiedDicom = locker.GetDicom();
 
         GetContext().GetIndex().ReconstructInstance(modifiedDicom, false, ResourceType_Instance /* dummy */);
       }
@@ -219,7 +219,7 @@ namespace Orthanc
     try
     {
       ServerContext::DicomCacheLocker locker(GetContext(), instance);
-      ParsedDicomFile& original = locker.GetDicom();
+      const ParsedDicomFile& original = locker.GetDicom();
 
       originalHasher.reset(new DicomInstanceHasher(original.GetHasher()));
       modified.reset(original.Clone(true));
@@ -238,7 +238,7 @@ namespace Orthanc
     {
       boost::recursive_mutex::scoped_lock lock(mutex_);  // DicomModification object is not thread safe, we must protect it from here
 
-      modification_->Apply(*modified);
+      modification_->Apply(modified);
 
       if (modification_->AreLabelsKept())
       {
@@ -261,7 +261,7 @@ namespace Orthanc
       source.AcquireParsed(*modified);  // "modified" is invalid below this point
       
       IDicomTranscoder::DicomImage transcoded;
-      if (GetContext().Transcode(transcoded, source, syntaxes, true))
+      if (GetContext().Transcode(transcoded, source, syntaxes, TranscodingSopInstanceUidMode_AllowNew))
       {
         modified.reset(transcoded.ReleaseAsParsedDicomFile());
 
@@ -719,7 +719,7 @@ namespace Orthanc
       }
 
       // and we must make sure that we overwite them with the modified resources
-      if (IsKeepSource() && !GetContext().IsOverwriteInstances())
+      if (!GetContext().IsOverwriteInstances())
       {
         throw OrthancException(ErrorCode_BadRequest,
                               "When keeping StudyInstanceUID, SeriesInstanceUID and SOPInstanceUID tag, you must have the 'OverwriteInstances' Orthanc configuration set to true in order to replace the modified resources");
