@@ -98,7 +98,7 @@ TEST(ServerConfig, AcceptedSopClasses)
       context.SetAcceptedSopClasses(acceptedStorageClasses, rejectedStorageClasses);
 
       context.GetAcceptedSopClasses(s, 0);
-      ASSERT_EQ(1, s.size());
+      ASSERT_EQ(1u, s.size());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.4") != s.end());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.12.1.1") == s.end());
     }
@@ -111,7 +111,7 @@ TEST(ServerConfig, AcceptedSopClasses)
       context.SetAcceptedSopClasses(acceptedStorageClasses, rejectedStorageClasses);
 
       context.GetAcceptedSopClasses(s, 0);
-      ASSERT_LE(10, s.size());
+      ASSERT_LE(10u, s.size());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.4") != s.end());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.12.1.1") == s.end());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.12.2.1") != s.end());
@@ -125,7 +125,7 @@ TEST(ServerConfig, AcceptedSopClasses)
       context.SetAcceptedSopClasses(acceptedStorageClasses, rejectedStorageClasses);
 
       context.GetAcceptedSopClasses(s, 0);
-      ASSERT_LE(10, s.size());
+      ASSERT_LE(10u, s.size());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.4") != s.end());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.12.1.1") == s.end());
       ASSERT_TRUE(s.find("1.2.840.10008.5.1.4.1.1.12.2.1") != s.end());
@@ -138,7 +138,7 @@ TEST(ServerConfig, AcceptedSopClasses)
       context.SetAcceptedSopClasses(acceptedStorageClasses, rejectedStorageClasses);
 
       context.GetAcceptedSopClasses(s, 0);
-      ASSERT_EQ(1, s.size());
+      ASSERT_EQ(1u, s.size());
       ASSERT_TRUE(s.find("1.2.3.4") != s.end());
     }
 
