@@ -141,10 +141,20 @@ namespace
     {
       return false;
     }
+
+    virtual void SetUserData(const Json::Value& userData) ORTHANC_OVERRIDE
+    {
+      throw OrthancException(ErrorCode_NotImplemented);
+    }
+
     virtual bool GetUserData(Json::Value& userData) const ORTHANC_OVERRIDE
     {
       return false;
     }
+
+    virtual void LookupErrorPayload(ErrorPayload& payload) const ORTHANC_OVERRIDE
+    {
+    }
   };
 
 
@@ -210,10 +220,20 @@ namespace
     {
       s = "DummyInstancesJob";
     }
+
+    virtual void SetUserData(const Json::Value& userData) ORTHANC_OVERRIDE
+    {
+      throw OrthancException(ErrorCode_NotImplemented);
+    }
+
     virtual bool GetUserData(Json::Value& userData) const ORTHANC_OVERRIDE
     {
       return false;
     }
+
+    virtual void LookupErrorPayload(ErrorPayload& payload) const ORTHANC_OVERRIDE
+    {
+    }
   };
 
 
@@ -1262,10 +1282,12 @@ TEST_F(OrthancJobsSerialization, DicomAssociationParameters)
 TEST_F(OrthancJobsSerialization, DicomMoveScuJob)
 {
   Json::Value command = Json::objectValue;
-  command["0008,0005"]["Type"] = "String";
-  command["0008,0005"]["Content"] = "ISO_IR 100";
-  command["0010,0020"]["Type"] = "String";
-  command["0010,0020"]["Content"] = "1234";
+  command["Query"]["0008,0005"]["Type"] = "String";
+  command["Query"]["0008,0005"]["Content"] = "ISO_IR 100";
+  command["Query"]["0010,0020"]["Type"] = "String";
+  command["Query"]["0010,0020"]["Content"] = "1234";
+  command["DimseErrorStatus"] = 0;
+  command["ReceivedInstancesIds"] = Json::arrayValue;
 
   Json::Value query = Json::objectValue;
   query["0010,0020"] = "456";
